@@ -1,6 +1,6 @@
 #include "CxxPreProcessor.h"
-#include <wx/regex.h>
 #include "file_logger.h"
+#include <wx/regex.h>
 
 CxxPreProcessor::CxxPreProcessor()
     : m_options(0)
@@ -13,15 +13,15 @@ CxxPreProcessor::~CxxPreProcessor() {}
 
 void CxxPreProcessor::Parse(const wxFileName& filename, size_t options)
 {
-    CxxPreProcessorScanner* scanner = NULL;
     try {
-        //CL_DEBUG("Calling CxxPreProcessor::Parse for file '%s'\n", filename.GetFullPath());
         m_options = options;
-        scanner = new CxxPreProcessorScanner(filename, m_options);
+        std::unordered_set<wxString> V;
+        CxxPreProcessorScanner scanner(filename, m_options, V);
+
         // Remove the option so recursive scanner won't get it
         m_options &= ~kLexerOpt_DontCollectMacrosDefinedInThisFile;
-        if(scanner && !scanner->IsNull()) {
-            scanner->Parse(this);
+        if(!scanner.IsNull()) {
+            scanner.Parse(this);
         }
     } catch(CxxLexerException& e) {
         wxUnusedVar(e);
@@ -29,21 +29,24 @@ void CxxPreProcessor::Parse(const wxFileName& filename, size_t options)
 
     // Delete all the 'deleteOnExit' tokens
     CxxPreProcessorToken::Map_t filteredMap;
-    CxxPreProcessorToken::Map_t::iterator iter = m_tokens.begin();
-    for(; iter != m_tokens.end(); ++iter) {
-        if(!iter->second.deleteOnExit) {
-            filteredMap.insert(std::make_pair(iter->first, iter->second));
+    filteredMap.reserve(m_tokens.size());
+
+    for(const auto& p : m_tokens) {
+        if(!p.second.deleteOnExit) {
+            filteredMap.insert(std::make_pair(p.first, p.second));
         }
     }
     m_tokens.swap(filteredMap);
-
-    // Make sure that the scanner is deleted
-    wxDELETE(scanner);
 }
 
-bool
-CxxPreProcessor::ExpandInclude(const wxFileName& currentFile, const wxString& includeStatement, wxFileName& outFile)
+bool CxxPreProcessor::ExpandInclude(const wxFileName& currentFile, const wxString& includeStatement,
+                                    wxFileName& outFile)
 {
+    // skip STL debug folders
+    if(includeStatement.StartsWith("<debug/")) {
+        return false;
+    }
+
     wxString includeName = includeStatement;
     includeName.Replace("\"", "");
     includeName.Replace("<", "");
@@ -58,7 +61,7 @@ CxxPreProcessor::ExpandInclude(const wxFileName& currentFile, const wxString& in
         return false;
     }
 
-    std::map<wxString, wxString>::iterator iter = m_fileMapping.find(includeStatement);
+    auto iter = m_fileMapping.find(includeStatement);
     if(iter != m_fileMapping.end()) {
         // if this file has a mapped file, it means that we either
         // already scanned it or could not find a match for it
@@ -70,21 +73,13 @@ CxxPreProcessor::ExpandInclude(const wxFileName& currentFile, const wxString& in
         wxString tmpfile;
         tmpfile << paths.Item(i) << "/" << includeName;
         wxFileName fn(tmpfile);
-        tmpfile = fn.GetFullPath();
-        // CL_DEBUG(" ... Checking include file: %s\n", fn.GetFullPath());
-        struct stat buff;
-        if((stat(tmpfile.mb_str(wxConvUTF8).data(), &buff) == 0)) {
-            //CL_DEBUG1(" ==> Creating scanner for file: %s\n", tmpfile);
-            wxFileName fixedFileName(tmpfile);
-            if(fixedFileName.FileExists()) {
-                fixedFileName.Normalize(wxPATH_NORM_DOTS);
-                tmpfile = fixedFileName.GetFullPath();
-                m_fileMapping.insert(std::make_pair(includeStatement, tmpfile));
-                outFile = fixedFileName;
-                return true;
-            } else {
-                //CL_DEBUG("Including a folder :/ : %s", fixedFileName.GetFullPath());
-            }
+        if(fn.FileExists()) {
+            fn.MakeAbsolute();
+            m_fileMapping.insert({ includeStatement, fn.GetFullPath() });
+            outFile = fn;
+            return true;
+        } else {
+            // CL_DEBUG("Including a folder :/ : %s", fixedFileName.GetFullPath());
         }
     }
 
@@ -136,20 +131,29 @@ wxString CxxPreProcessor::GetGxxCommand(const wxString& gxx, const wxString& fil
 void CxxPreProcessor::SetIncludePaths(const wxArrayString& includePaths)
 {
     m_includePaths.Clear();
+    m_includePaths.reserve(includePaths.size());
+
+    std::unordered_set<wxString> S;
+    S.reserve(includePaths.size());
+
     for(size_t i = 0; i < includePaths.GetCount(); ++i) {
         wxString path = includePaths.Item(i);
         path.Trim().Trim(false);
-        if(path.IsEmpty()) continue;
+        if(path.IsEmpty()) {
+            continue;
+        }
 
-        if(m_includePaths.Index(path) == wxNOT_FOUND) {
+        if(S.count(path) == 0) {
             m_includePaths.Add(path);
+            S.insert(path);
         }
     }
 }
 
 bool CxxPreProcessor::CanGoDeeper() const
 {
-    if(m_maxDepth == -1) return true;
+    if(m_maxDepth == -1)
+        return true;
     return m_currentDepth < m_maxDepth;
 }
 
