@@ -24,12 +24,15 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "JSON.h"
+
+#include "StringUtils.h"
 #include "clFontHelper.h"
 #include "fileutils.h"
+#include "wx/dynarray.h"
+
 #include <stdlib.h>
 #include <wx/ffile.h>
 #include <wx/filename.h>
-#include "StringUtils.h"
 
 JSON::JSON(const wxString& text)
     : m_json(NULL)
@@ -62,7 +65,9 @@ JSON::JSON(const wxFileName& filename)
     : m_json(NULL)
 {
     wxString content;
-    if(!FileUtils::ReadFileContent(filename, content)) { return; }
+    if(!FileUtils::ReadFileContent(filename, content)) {
+        return;
+    }
     m_json = cJSON_Parse(content.mb_str(wxConvUTF8).data());
 }
 
@@ -85,7 +90,9 @@ void JSON::save(const wxFileName& fn) const
 
 JSONItem JSON::toElement() const
 {
-    if(!m_json) { return JSONItem(NULL); }
+    if(!m_json) {
+        return JSONItem(NULL);
+    }
     return JSONItem(m_json);
 }
 
@@ -93,10 +100,14 @@ wxString JSON::errorString() const { return _errorString; }
 
 JSONItem JSONItem::namedObject(const wxString& name) const
 {
-    if(!m_json) { return JSONItem(NULL); }
+    if(!m_json) {
+        return JSONItem(NULL);
+    }
 
     cJSON* obj = cJSON_GetObjectItem(m_json, name.mb_str(wxConvUTF8).data());
-    if(!obj) { return JSONItem(NULL); }
+    if(!obj) {
+        return JSONItem(NULL);
+    }
     return JSONItem(obj);
 }
 
@@ -142,17 +153,15 @@ JSONItem::JSONItem(const wxString& name, double val)
 JSONItem::JSONItem(const wxString& name, const std::string& val)
     : m_name(name)
     , m_type(cJSON_String)
+    , m_valueString(val)
 {
-    m_valueString.reserve(val.length() + 1);
-    m_valueString.append(val);
 }
 
 JSONItem::JSONItem(const wxString& name, const char* pval, size_t len)
     : m_name(name)
     , m_type(cJSON_String)
+    , m_valueString(pval, len)
 {
-    m_valueString.reserve(len + 1);
-    m_valueString.append(pval);
 }
 
 JSONItem::JSONItem(const wxString& name, bool val)
@@ -161,59 +170,89 @@ JSONItem::JSONItem(const wxString& name, bool val)
 {
 }
 
+JSONItem JSONItem::operator[](int index) const
+{
+    if(isArray()) {
+        return arrayItem(index);
+    }
+    return JSONItem(NULL);
+}
+
+JSONItem JSONItem::operator[](const wxString& name) const { return namedObject(name); }
+
 JSONItem JSONItem::arrayItem(int pos) const
 {
-    if(!m_json) { return JSONItem(NULL); }
+    if(!m_json) {
+        return JSONItem(NULL);
+    }
 
-    if(m_json->type != cJSON_Array) return JSONItem(NULL);
+    if(m_json->type != cJSON_Array)
+        return JSONItem(NULL);
 
     int size = cJSON_GetArraySize(m_json);
-    if(pos >= size) return JSONItem(NULL);
+    if(pos >= size)
+        return JSONItem(NULL);
 
     return JSONItem(cJSON_GetArrayItem(m_json, pos));
 }
 
 bool JSONItem::isNull() const
 {
-    if(!m_json) { return false; }
+    if(!m_json) {
+        return false;
+    }
     return m_json->type == cJSON_NULL;
 }
 
 bool JSONItem::toBool(bool defaultValue) const
 {
-    if(!m_json) { return defaultValue; }
+    if(!m_json) {
+        return defaultValue;
+    }
 
-    if(!isBool()) { return defaultValue; }
+    if(!isBool()) {
+        return defaultValue;
+    }
 
     return m_json->type == cJSON_True;
 }
 
 wxString JSONItem::toString(const wxString& defaultValue) const
 {
-    if(!m_json) { return defaultValue; }
+    if(!m_json) {
+        return defaultValue;
+    }
 
-    if(m_json->type != cJSON_String) { return defaultValue; }
+    if(m_json->type != cJSON_String) {
+        return defaultValue;
+    }
 
     return wxString(m_json->valuestring, wxConvUTF8);
 }
 
 bool JSONItem::isBool() const
 {
-    if(!m_json) { return false; }
+    if(!m_json) {
+        return false;
+    }
 
     return m_json->type == cJSON_True || m_json->type == cJSON_False;
 }
 
 bool JSONItem::isString() const
 {
-    if(!m_json) { return false; }
+    if(!m_json) {
+        return false;
+    }
 
     return m_json->type == cJSON_String;
 }
 
 void JSONItem::append(const JSONItem& element)
 {
-    if(!m_json) { return; }
+    if(!m_json) {
+        return;
+    }
 
     switch(element.getType()) {
     case cJSON_False:
@@ -243,9 +282,35 @@ void JSONItem::append(const JSONItem& element)
     }
 }
 
+void JSONItem::arrayAppend(const char* value)
+{
+    if(!m_json) {
+        return;
+    }
+    cJSON* p = cJSON_CreateString(value);
+    cJSON_AddItemToArray(m_json, p);
+}
+
+void JSONItem::arrayAppend(const std::string& value) { arrayAppend((const char*)value.c_str()); }
+
+void JSONItem::arrayAppend(double number)
+{
+    if(!m_json) {
+        return;
+    }
+    cJSON* p = cJSON_CreateNumber(number);
+    cJSON_AddItemToArray(m_json, p);
+}
+
+void JSONItem::arrayAppend(int number) { arrayAppend((double)number); }
+
+void JSONItem::arrayAppend(const wxString& value) { arrayAppend((const char*)value.mb_str(wxConvUTF8).data()); }
+
 void JSONItem::arrayAppend(const JSONItem& element)
 {
-    if(!m_json) { return; }
+    if(!m_json) {
+        return;
+    }
 
     cJSON* p = NULL;
     switch(element.getType()) {
@@ -273,7 +338,9 @@ void JSONItem::arrayAppend(const JSONItem& element)
         p = element.m_json;
         break;
     }
-    if(p) { cJSON_AddItemToArray(m_json, p); }
+    if(p) {
+        cJSON_AddItemToArray(m_json, p);
+    }
 }
 
 JSONItem JSONItem::createArray(const wxString& name)
@@ -294,7 +361,9 @@ JSONItem JSONItem::createObject(const wxString& name)
 
 char* JSONItem::FormatRawString(bool formatted) const
 {
-    if(!m_json) { return NULL; }
+    if(!m_json) {
+        return NULL;
+    }
 
     if(formatted) {
         return cJSON_Print(m_json);
@@ -306,46 +375,63 @@ char* JSONItem::FormatRawString(bool formatted) const
 
 wxString JSONItem::format(bool formatted) const
 {
-    if(!m_json) { return wxT(""); }
+    if(!m_json) {
+        return wxT("");
+    }
 
     char* p = formatted ? cJSON_Print(m_json) : cJSON_PrintUnformatted(m_json);
-    wxString s(p, wxConvISO8859_1);
+    wxString s(p, wxConvUTF8);
     free(p);
     return s;
 }
 
 int JSONItem::toInt(int defaultVal) const
 {
-    if(!m_json) { return defaultVal; }
+    if(!m_json) {
+        return defaultVal;
+    }
 
-    if(m_json->type != cJSON_Number) { return defaultVal; }
+    if(m_json->type != cJSON_Number) {
+        return defaultVal;
+    }
 
     return m_json->valueint;
 }
 
 size_t JSONItem::toSize_t(size_t defaultVal) const
 {
-    if(!m_json) { return defaultVal; }
+    if(!m_json) {
+        return defaultVal;
+    }
 
-    if(m_json->type != cJSON_Number) { return defaultVal; }
+    if(m_json->type != cJSON_Number) {
+        return defaultVal;
+    }
 
     return (size_t)m_json->valueint;
 }
 
 double JSONItem::toDouble(double defaultVal) const
 {
-    if(!m_json) { return defaultVal; }
+    if(!m_json) {
+        return defaultVal;
+    }
 
-    if(m_json->type != cJSON_Number) { return defaultVal; }
+    if(m_json->type != cJSON_Number) {
+        return defaultVal;
+    }
 
     return m_json->valuedouble;
 }
 
 int JSONItem::arraySize() const
 {
-    if(!m_json) { return 0; }
+    if(!m_json) {
+        return 0;
+    }
 
-    if(m_json->type != cJSON_Array) return 0;
+    if(m_json->type != cJSON_Array)
+        return 0;
 
     return cJSON_GetArraySize(m_json);
 }
@@ -358,7 +444,7 @@ JSONItem& JSONItem::addProperty(const wxString& name, bool value)
 
 JSONItem& JSONItem::addProperty(const wxString& name, const wxString& value)
 {
-    const wxCharBuffer cb = value.mbc_str();
+    const wxCharBuffer cb = value.mb_str(wxConvUTF8);
     append(JSONItem(name, cb.data(), cb.length()));
     return *this;
 }
@@ -371,8 +457,7 @@ JSONItem& JSONItem::addProperty(const wxString& name, const std::string& value)
 
 JSONItem& JSONItem::addProperty(const wxString& name, const wxChar* value)
 {
-    append(JSONItem(name, wxString(value), cJSON_String));
-    return *this;
+    return addProperty(name, wxString(value));
 }
 
 JSONItem& JSONItem::addProperty(const wxString& name, long value)
@@ -391,24 +476,36 @@ JSONItem& JSONItem::addProperty(const wxString& name, const wxArrayString& arr)
     return *this;
 }
 
-void JSONItem::arrayAppend(const wxString& value) { arrayAppend(JSONItem(wxT(""), value, cJSON_String)); }
-
 wxArrayString JSONItem::toArrayString(const wxArrayString& defaultValue) const
 {
-    if(!m_json) { return defaultValue; }
+    if(!m_json) {
+        return defaultValue;
+    }
 
-    if(m_json->type != cJSON_Array) { return defaultValue; }
+    if(m_json->type != cJSON_Array) {
+        return defaultValue;
+    }
+
+    int arr_size = arraySize();
+    if(arr_size == 0) {
+        return defaultValue;
+    }
 
     wxArrayString arr;
-    for(int i = 0; i < arraySize(); i++) {
-        arr.Add(arrayItem(i).toString());
+    arr.reserve(arr_size);
+    auto child = m_json->child;
+    while(child) {
+        arr.push_back(wxString(child->valuestring, wxConvUTF8));
+        child = child->next;
     }
     return arr;
 }
 
 bool JSONItem::hasNamedObject(const wxString& name) const
 {
-    if(!m_json) { return false; }
+    if(!m_json) {
+        return false;
+    }
 
     cJSON* obj = cJSON_GetObjectItem(m_json, name.mb_str(wxConvUTF8).data());
     return obj != NULL;
@@ -430,25 +527,34 @@ JSONItem& JSONItem::addProperty(const wxString& name, const wxSize& sz)
 
 wxPoint JSONItem::toPoint() const
 {
-    if(!m_json) { return wxDefaultPosition; }
+    if(!m_json) {
+        return wxDefaultPosition;
+    }
 
-    if(m_json->type != cJSON_String) { return wxDefaultPosition; }
+    if(m_json->type != cJSON_String) {
+        return wxDefaultPosition;
+    }
 
     wxString str = m_json->valuestring;
     wxString x = str.BeforeFirst(',');
     wxString y = str.AfterFirst(',');
 
     long nX(-1), nY(-1);
-    if(!x.ToLong(&nX) || !y.ToLong(&nY)) return wxDefaultPosition;
+    if(!x.ToLong(&nX) || !y.ToLong(&nY))
+        return wxDefaultPosition;
 
     return wxPoint(nX, nY);
 }
 
 wxColour JSONItem::toColour(const wxColour& defaultColour) const
 {
-    if(!m_json) { return defaultColour; }
+    if(!m_json) {
+        return defaultColour;
+    }
 
-    if(m_json->type != cJSON_String) { return defaultColour; }
+    if(m_json->type != cJSON_String) {
+        return defaultColour;
+    }
     return wxColour(m_json->valuestring);
 }
 
@@ -461,7 +567,9 @@ wxSize JSONItem::toSize() const
 
 JSONItem& JSONItem::addProperty(const wxString& name, const JSONItem& element)
 {
-    if(!m_json) { return *this; }
+    if(!m_json) {
+        return *this;
+    }
     cJSON_AddItemToObject(m_json, name.mb_str(wxConvUTF8).data(), element.m_json);
     return *this;
 }
@@ -469,13 +577,16 @@ JSONItem& JSONItem::addProperty(const wxString& name, const JSONItem& element)
 void JSONItem::removeProperty(const wxString& name)
 {
     // delete child property
-    if(!m_json) { return; }
+    if(!m_json) {
+        return;
+    }
     cJSON_DeleteItemFromObject(m_json, name.mb_str(wxConvUTF8).data());
 }
 #if wxUSE_GUI
 JSONItem& JSONItem::addProperty(const wxString& name, const wxStringMap_t& stringMap)
 {
-    if(!m_json) return *this;
+    if(!m_json)
+        return *this;
 
     JSONItem arr = JSONItem::createArray(name);
     wxStringMap_t::const_iterator iter = stringMap.begin();
@@ -492,9 +603,13 @@ JSONItem& JSONItem::addProperty(const wxString& name, const wxStringMap_t& strin
 wxStringMap_t JSONItem::toStringMap() const
 {
     wxStringMap_t res;
-    if(!m_json) { return res; }
+    if(!m_json) {
+        return res;
+    }
 
-    if(m_json->type != cJSON_Array) { return res; }
+    if(m_json->type != cJSON_Array) {
+        return res;
+    }
 
     for(int i = 0; i < arraySize(); ++i) {
         wxString key = arrayItem(i).namedObject("key").toString();
@@ -509,16 +624,22 @@ JSONItem& JSONItem::addProperty(const wxString& name, size_t value) { return add
 JSONItem& JSONItem::addProperty(const wxString& name, const wxColour& colour)
 {
     wxString colourValue;
-    if(colour.IsOk()) { colourValue = colour.GetAsString(wxC2S_HTML_SYNTAX); }
+    if(colour.IsOk()) {
+        colourValue = colour.GetAsString(wxC2S_HTML_SYNTAX);
+    }
     return addProperty(name, colourValue);
 }
 #endif
 JSONItem JSONItem::firstChild()
 {
     m_walker = NULL;
-    if(!m_json) { return JSONItem(NULL); }
+    if(!m_json) {
+        return JSONItem(NULL);
+    }
 
-    if(!m_json->child) { return JSONItem(NULL); }
+    if(!m_json->child) {
+        return JSONItem(NULL);
+    }
 
     m_walker = m_json->child;
     return JSONItem(m_walker);
@@ -526,7 +647,9 @@ JSONItem JSONItem::firstChild()
 
 JSONItem JSONItem::nextChild()
 {
-    if(!m_walker) { return JSONItem(NULL); }
+    if(!m_walker) {
+        return JSONItem(NULL);
+    }
 
     JSONItem element(m_walker->next);
     m_walker = m_walker->next;
@@ -546,7 +669,8 @@ JSONItem& JSONItem::addProperty(const wxString& name, const wxFont& font)
 wxFont JSONItem::toFont(const wxFont& defaultFont) const
 {
     wxString str = toString();
-    if(str.IsEmpty()) return defaultFont;
+    if(str.IsEmpty())
+        return defaultFont;
     wxFont f = clFontHelper::FromString(str);
     return f;
 }
@@ -554,26 +678,34 @@ wxFont JSONItem::toFont(const wxFont& defaultFont) const
 
 bool JSONItem::isArray() const
 {
-    if(!m_json) { return false; }
+    if(!m_json) {
+        return false;
+    }
     return m_json->type == cJSON_Array;
 }
 
 bool JSONItem::isNumber() const
 {
-    if(!m_json) { return false; }
+    if(!m_json) {
+        return false;
+    }
     return m_json->type == cJSON_Number;
 }
 
 JSONItem JSONItem::detachProperty(const wxString& name)
 {
-    if(!m_json) { return JSONItem(NULL); }
+    if(!m_json) {
+        return JSONItem(NULL);
+    }
     cJSON* j = cJSON_DetachItemFromObject(m_json, name.c_str());
     return JSONItem(j);
 }
 
 wxFileName JSONItem::toFileName() const
 {
-    if(!m_json) { return wxFileName(); }
+    if(!m_json) {
+        return wxFileName();
+    }
     return wxFileName(m_valueString);
 }
 
@@ -581,3 +713,103 @@ JSONItem& JSONItem::addProperty(const wxString& name, const wxFileName& filename
 {
     return addProperty(name, filename.GetFullPath());
 }
+
+JSONItem JSONItem::AddArray(const wxString& name)
+{
+    JSONItem json = createArray(name);
+    append(json);
+    return json;
+}
+
+JSONItem JSONItem::AddObject(const wxString& name)
+{
+    JSONItem json = createObject(name);
+    append(json);
+    return json;
+}
+
+JSONItem& JSONItem::addProperty(const wxString& name, cJSON* pjson)
+{
+    if(!m_json) {
+        return *this;
+    }
+    cJSON_AddItemToObject(m_json, name.mb_str(wxConvUTF8).data(), pjson);
+    return *this;
+}
+
+std::vector<double> JSONItem::toDoubleArray(const std::vector<double>& defaultValue) const
+{
+    if(!m_json) {
+        return defaultValue;
+    }
+
+    if(m_json->type != cJSON_Array) {
+        return defaultValue;
+    }
+
+    int arr_size = arraySize();
+    if(arr_size == 0) {
+        return defaultValue;
+    }
+
+    std::vector<double> arr;
+    arr.reserve(arr_size);
+    auto child = m_json->child;
+    while(child) {
+        arr.push_back(child->valuedouble);
+        child = child->next;
+    }
+    return arr;
+}
+
+std::vector<int> JSONItem::toIntArray(const std::vector<int>& defaultValue) const
+{
+    if(!m_json) {
+        return defaultValue;
+    }
+
+    if(m_json->type != cJSON_Array) {
+        return defaultValue;
+    }
+
+    int arr_size = arraySize();
+    if(arr_size == 0) {
+        return defaultValue;
+    }
+
+    std::vector<int> arr;
+    arr.reserve(arr_size);
+    auto child = m_json->child;
+    while(child) {
+        arr.push_back(child->valueint);
+        child = child->next;
+    }
+    return arr;
+}
+
+JSONItem& JSONItem::addProperty(const wxString& name, const std::vector<int>& arr_int)
+{
+    if(!m_json) {
+        return *this;
+    }
+
+    if(m_type != cJSON_Object) {
+        return *this;
+    }
+
+    // create array
+    JSONItem arr = AddArray(name);
+    for(size_t i = 0; i < arr_int.size(); ++i) {
+        cJSON_AddItemToArray(arr.m_json, cJSON_CreateNumber(arr_int[i]));
+    }
+    return *this;
+}
+
+JSONItem& JSONItem::addProperty(const wxString& name, const wxVector<int>& arr_int)
+{
+    std::vector<int> V;
+    V.reserve(arr_int.size());
+
+    V.insert(V.end(), arr_int.begin(), arr_int.end());
+    return addProperty(name, V);
+}
