@@ -24,18 +24,19 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "clSocketBase.h"
+#include "file_logger.h"
 #include <cerrno>
 #include <cstdio>
-#include <sstream>
 #include <memory>
+#include <sstream>
 
 #ifndef _WIN32
 #include <fcntl.h>
-#include <unistd.h>
-#include <sys/select.h>
 #include <string.h>
-#include <sys/types.h>
+#include <sys/select.h>
 #include <sys/socket.h>
+#include <sys/types.h>
+#include <unistd.h>
 #endif
 
 clSocketBase::clSocketBase(socket_t sockfd)
@@ -109,7 +110,7 @@ int clSocketBase::Read(char* buffer, size_t bufferSize, size_t& bytesRead, long
         return kTimeout;
     }
     memset(buffer, 0, bufferSize);
-    const int res = recv(m_socket, buffer, bufferSize, 0);
+    const int res = ::recv(m_socket, buffer, bufferSize, 0);
 
     if(res < 0) {
         const int err = GetLastError();
@@ -118,8 +119,7 @@ int clSocketBase::Read(char* buffer, size_t bufferSize, size_t& bytesRead, long
         }
 
         throw clSocketException("Read failed: " + error(err));
-    }
-    else if(0 == res) {
+    } else if(0 == res) {
         throw clSocketException("Read failed: " + error());
     }
 
@@ -186,10 +186,19 @@ void clSocketBase::Send(const wxMemoryBuffer& msg)
     }
     char* pdata = (char*)msg.GetData();
     int bytesLeft = msg.GetDataLen();
+    
+    std::string str(pdata, bytesLeft);
+    clDEBUG1() << "Sending buffer:" << str << endl;
+    clDEBUG1() << "Message length:" << str.length() << endl;
     while(bytesLeft) {
-        if(SelectWriteMS(1000) == kTimeout) continue;
+        if(SelectWriteMS(100) == kTimeout) {
+            continue;
+        }
         int bytesSent = ::send(m_socket, (const char*)pdata, bytesLeft, 0);
-        if(bytesSent <= 0) throw clSocketException("Send error: " + error());
+        clDEBUG1() << "::send() completed. number of bytes sent:" << bytesSent << endl;
+        if(bytesSent <= 0) {
+            throw clSocketException("Send error: " + error());
+        }
         pdata += bytesSent;
         bytesLeft -= bytesSent;
     }
@@ -204,27 +213,20 @@ int clSocketBase::GetLastError()
 #endif
 }
 
-std::string clSocketBase::error()
-{
-    return error(GetLastError());
-}
+std::string clSocketBase::error() { return error(GetLastError()); }
 
 std::string clSocketBase::error(const int errorCode)
 {
     std::string err;
 #ifdef _WIN32
     // Get the error message, if any.
-    if(errorCode == 0) return "No error message has been recorded";
+    if(errorCode == 0)
+        return "No error message has been recorded";
 
     LPSTR messageBuffer = nullptr;
     size_t size =
         FormatMessageA(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-                       NULL,
-                       errorCode,
-                       MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-                       (LPSTR)&messageBuffer,
-                       0,
-                       NULL);
+                       NULL, errorCode, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (LPSTR)&messageBuffer, 0, NULL);
 
     std::string message(messageBuffer, size);
 
@@ -307,7 +309,7 @@ void clSocketBase::WriteMessage(const wxString& message)
     memset(msglen, 0, sizeof(msglen));
     sprintf(msglen, "%010d", len);
     // send it without the NULL byte
-    if(::write(m_socket, msglen, sizeof(msglen) - 1) < 0) {
+    if(::send(m_socket, msglen, sizeof(msglen) - 1, 0) < 0) {
         throw clSocketException("Send error: " + error(errno));
     }
 
@@ -435,3 +437,9 @@ int clSocketBase::SelectReadMS(long milliSeconds)
         return kSuccess;
     }
 }
+
+void clSocketBase::SetSocket(socket_t socket)
+{
+    SetCloseOnExit(false);
+    m_socket = socket;
+}
