@@ -27,6 +27,10 @@
 #define FILELOGGER_H
 
 #include "codelite_exports.h"
+#include "macros.h"
+
+#include <vector>
+#include <wx/colour.h>
 #include <wx/ffile.h>
 #include <wx/filename.h>
 #include <wx/stopwatch.h>
@@ -65,6 +69,12 @@ public:
     }
 
     int GetRequestedLogLevel() const { return _requestedLogLevel; }
+    static int GetCurrentLogLevel() { return m_verbosity; }
+
+    /**
+     * @brief return true if log_level is lower than the currently set log level
+     */
+    static bool CanLog(int log_level) { return log_level <= GetCurrentLogLevel(); }
 
     /**
      * @brief give a thread-id a unique name which will be displayed in log
@@ -106,17 +116,19 @@ public:
         return *this;
     }
 
-    /**
-     * @brief special wxArrayString printing
-     */
-    inline FileLogger& operator<<(const wxArrayString& arr)
+    // special types printing
+    inline FileLogger& operator<<(const std::vector<wxString>& arr)
     {
-        if(GetRequestedLogLevel() > m_verbosity) { return *this; }
-        if(!m_buffer.IsEmpty()) { m_buffer << " "; }
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+        if(!m_buffer.IsEmpty()) {
+            m_buffer << " ";
+        }
         m_buffer << "[";
-        if(!arr.IsEmpty()) {
+        if(!arr.empty()) {
             for(size_t i = 0; i < arr.size(); ++i) {
-                m_buffer << arr.Item(i) << ", ";
+                m_buffer << arr[i] << ", ";
             }
             m_buffer.RemoveLast(2);
         }
@@ -124,6 +136,64 @@ public:
         return *this;
     }
 
+    inline FileLogger& operator<<(const wxStringSet_t& S)
+    {
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+        if(!m_buffer.IsEmpty()) {
+            m_buffer << " ";
+        }
+        m_buffer << "{";
+        if(!S.empty()) {
+            for(const wxString& s : S) {
+                m_buffer << s << ", ";
+            }
+            m_buffer.RemoveLast(2);
+        }
+        m_buffer << "}";
+        return *this;
+    }
+
+    inline FileLogger& operator<<(const wxStringMap_t& M)
+    {
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+        if(!m_buffer.IsEmpty()) {
+            m_buffer << " ";
+        }
+        m_buffer << "{";
+        if(!M.empty()) {
+            for(const auto& vt : M) {
+                m_buffer << "{" << vt.first << ", " << vt.second << "}, ";
+            }
+            m_buffer.RemoveLast(2);
+        }
+        m_buffer << "}";
+        return *this;
+    }
+
+    inline FileLogger& operator<<(const wxArrayString& arr)
+    {
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+        std::vector<wxString> v{ arr.begin(), arr.end() };
+        *this << v;
+        return *this;
+    }
+
+    inline FileLogger& operator<<(const wxColour& colour)
+    {
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+
+        *this << colour.GetAsString(wxC2S_HTML_SYNTAX);
+        return *this;
+    }
+
     /**
      * @brief special wxString printing
      * Without this overload operator, on some compilers, the "clDEBUG()<< wxString" might be "going" to the one
@@ -131,8 +201,12 @@ public:
      */
     inline FileLogger& operator<<(const wxString& str)
     {
-        if(GetRequestedLogLevel() > m_verbosity) { return *this; }
-        if(!m_buffer.IsEmpty()) { m_buffer << " "; }
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+        if(!m_buffer.IsEmpty()) {
+            m_buffer << " ";
+        }
         m_buffer << str;
         return *this;
     }
@@ -142,8 +216,12 @@ public:
      */
     inline FileLogger& operator<<(const wxFileName& fn)
     {
-        if(GetRequestedLogLevel() > m_verbosity) { return *this; }
-        if(!m_buffer.IsEmpty()) { m_buffer << " "; }
+        if(GetRequestedLogLevel() > m_verbosity) {
+            return *this;
+        }
+        if(!m_buffer.IsEmpty()) {
+            m_buffer << " ";
+        }
         m_buffer << fn.GetFullPath();
         return *this;
     }
@@ -153,8 +231,12 @@ public:
      */
     template <typename T> FileLogger& Append(const T& elem, int level)
     {
-        if(level > m_verbosity) { return *this; }
-        if(!m_buffer.IsEmpty()) { m_buffer << " "; }
+        if(level > m_verbosity) {
+            return *this;
+        }
+        if(!m_buffer.IsEmpty()) {
+            m_buffer << " ";
+        }
         m_buffer << elem;
         return *this;
     }
@@ -171,6 +253,12 @@ inline FileLogger& clEndl(FileLogger& d)
     return d;
 }
 
+inline FileLogger& endl(FileLogger& d)
+{
+    d.Flush();
+    return d;
+}
+
 template <typename T> FileLogger& operator<<(FileLogger& logger, const T& obj)
 {
     logger.Append(obj, logger.GetRequestedLogLevel());
