@@ -22,11 +22,13 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "findinfilesdlg.h"
+
 #include "ColoursAndFontsManager.h"
 #include "FindInFilesLocationsDlg.h"
 #include "clWorkspaceManager.h"
 #include "dirpicker.h"
-#include "findinfilesdlg.h"
+#include "event_notifier.h"
 #include "findresultstab.h"
 #include "frame.h"
 #include "globals.h"
@@ -38,6 +40,7 @@
 #include "sessionmanager.h"
 #include "windowattrmanager.h"
 #include "workspace.h"
+
 #include <algorithm>
 #include <project.h>
 #include <wx/fontmap.h>
@@ -45,30 +48,70 @@
 #include <wx/wupdlock.h>
 #include <wxStringHash.h>
 
-FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data)
+namespace
+{
+const wxString RE_TODO = "(/[/\\*]+ *TODO)";
+const wxString RE_BUG = "(/[/\\*]+ *BUG)";
+const wxString RE_ATTN = "(/[/\\*]+ *ATTN)";
+const wxString RE_FIXME = "(/[/\\*]+ *FIXME)";
+} // namespace
+
+FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data, wxWindow* handler)
     : FindInFilesDialogBase(parent, wxID_ANY)
     , m_data(data)
+    , m_handler(handler)
 {
-    LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("text");
-    if(lexer) {
-        lexer->Apply(m_stcPaths);
-    }
-    m_stcPaths->SetEOLMode(wxSTC_EOL_LF);
-
     // Store the find-in-files data
     wxString filemask = SessionManager::Get().GetFindInFilesMaskForCurrentWorkspace();
     if(!filemask.IsEmpty()) {
         m_data.SetSelectedMask(filemask);
     }
-    DoSetSearchPaths(m_data.GetSearchPaths());
+
+    m_comboBoxWhere->Clear();
+    m_comboBoxWhere->Append(m_data.GetWhereOptions());
+    m_comboBoxWhere->SetValue(m_data.GetWhere());
+    m_comboBoxWhere->AddCommand(wxID_CLEAR, _("Clear history"));
+    m_comboBoxWhere->Bind(
+        wxEVT_MENU,
+        [&](wxCommandEvent& e) {
+            wxUnusedVar(e);
+            m_comboBoxWhere->Clear();
+        },
+        wxID_CLEAR);
 
     // Search for
+    m_findString->AddCommand(wxID_CLEAR, _("Clear history"));
     m_findString->Clear();
     m_findString->Append(m_data.GetFindStringArr());
+    m_findString->Bind(
+        wxEVT_MENU,
+        [&](wxCommandEvent& e) {
+            wxUnusedVar(e);
+            m_findString->Clear();
+        },
+        wxID_CLEAR);
+
     m_findString->SetValue(m_data.GetFindString());
+    m_replaceString->AddCommand(wxID_CLEAR, _("Clear history"));
     m_replaceString->Append(m_data.GetReplaceStringArr());
     m_replaceString->SetValue(m_data.GetReplaceString());
+    m_replaceString->Bind(
+        wxEVT_MENU,
+        [&](wxCommandEvent& e) {
+            wxUnusedVar(e);
+            m_replaceString->Clear();
+        },
+        wxID_CLEAR);
+
+    m_fileTypes->AddCommand(wxID_CLEAR, _("Clear history"));
     m_fileTypes->SetSelection(0);
+    m_fileTypes->Bind(
+        wxEVT_MENU,
+        [&](wxCommandEvent& e) {
+            wxUnusedVar(e);
+            m_fileTypes->Clear();
+        },
+        wxID_CLEAR);
 
     m_matchCase->SetValue(m_data.GetFlags() & wxFRD_MATCHCASE);
     m_matchWholeWord->SetValue(m_data.GetFlags() & wxFRD_MATCHWHOLEWORD);
@@ -76,6 +119,10 @@ FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data)
     m_checkBoxSaveFilesBeforeSearching->SetValue(m_data.GetFlags() & wxFRD_SAVE_BEFORE_SEARCH);
     m_checkBoxPipeForGrep->SetValue(m_data.GetFlags() & wxFRD_ENABLE_PIPE_SUPPORT);
 
+    // keep the current regex value, in case user uses the presets and we want
+    // to restore it back
+    m_oldRegexValue = m_data.GetFlags() & wxFRD_REGULAREXPRESSION;
+
     // Set encoding
     static wxArrayString astrEncodings;
     static std::unordered_map<wxString, int> encodingMap;
@@ -101,20 +148,19 @@ FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data)
         selection = encodingMap.count(m_data.GetEncoding()) ? encodingMap.find(m_data.GetEncoding())->second : 0;
     }
 
-    m_choiceEncoding->Append(astrEncodings);
-    if(m_choiceEncoding->GetCount()) {
-        m_choiceEncoding->SetSelection(selection);
+    m_comboBoxEncoding->Append(astrEncodings);
+    if(m_comboBoxEncoding->GetCount()) {
+        m_comboBoxEncoding->SetSelection(selection);
     }
 
     // Set the file mask
     DoSetFileMask();
     SetName("FindInFilesDialog");
+    CallAfter(&FindInFilesDialog::DoSelectAll);
 
     // Fit the initial size and set it as the default minimum size
     GetSizer()->Fit(this);
     SetMinSize(GetSize());
-    CallAfter(&FindInFilesDialog::DoSelectAll);
-    ::clSetSmallDialogBestSizeAndPosition(this);
 }
 
 FindInFilesDialog::~FindInFilesDialog() { BuildFindReplaceData(); }
@@ -152,7 +198,8 @@ void FindInFilesDialog::DoSetFileMask()
 void FindInFilesDialog::DoSearchReplace()
 {
     SearchData data = DoGetSearchData();
-    data.SetOwner(clMainFrame::Get()->GetOutputPane()->GetReplaceResultsTab());
+    // direct output results to the 'Replace' tab, unless a custom handler was provided
+    data.SetOwner(m_handler ? m_handler : clMainFrame::Get()->GetOutputPane()->GetReplaceResultsTab());
     DoSaveOpenFiles();
     SearchThreadST::Get()->PerformSearch(data);
     BuildFindReplaceData();
@@ -162,7 +209,8 @@ void FindInFilesDialog::DoSearchReplace()
 void FindInFilesDialog::DoSearch()
 {
     SearchData data = DoGetSearchData();
-    data.SetOwner(clMainFrame::Get()->GetOutputPane()->GetFindResultsTab());
+    // direct results to the 'Search' tab
+    data.SetOwner(m_handler ? m_handler : clMainFrame::Get()->GetOutputPane()->GetFindResultsTab());
 
     // check to see if we require to save the files
     DoSaveOpenFiles();
@@ -195,7 +243,7 @@ SearchData FindInFilesDialog::DoGetSearchData()
     data.SetMatchWholeWord((flags & wxFRD_MATCHWHOLEWORD) != 0);
     data.SetRegularExpression((flags & wxFRD_REGULAREXPRESSION) != 0);
     data.SetDisplayScope((flags & wxFRD_DISPLAYSCOPE) != 0);
-    data.SetEncoding(m_choiceEncoding->GetStringSelection());
+    data.SetEncoding(m_comboBoxEncoding->GetStringSelection());
     data.SetSkipComments(flags & wxFRD_SKIP_COMMENTS);
     data.SetSkipStrings(flags & wxFRD_SKIP_STRINGS);
     data.SetColourComments(flags & wxFRD_COLOUR_COMMENTS);
@@ -239,8 +287,11 @@ SearchData FindInFilesDialog::DoGetSearchData()
             wxString projectName = rootDir.Mid(3);
             DoAddProjectFiles(projectName, files);
 
-        } else if((rootDir == wxGetTranslation(SEARCH_IN_WORKSPACE_FOLDER)) &&
-                  clWorkspaceManager::Get().IsWorkspaceOpened()) {
+        } else if((rootDir == wxGetTranslation(SEARCH_IN_WORKSPACE_FOLDER)) ||
+                  (rootDir == SEARCH_IN_WORKSPACE_FOLDER)) {
+            if(!clWorkspaceManager::Get().IsWorkspaceOpened()) {
+                continue;
+            }
             // Add the workspace folder
             rootDirs.Add(clWorkspaceManager::Get().GetWorkspace()->GetFileName().GetPath());
 
@@ -327,36 +378,27 @@ void FindInFilesDialog::OnClose(wxCloseEvent& e) { Destroy(); }
 
 void FindInFilesDialog::OnAddPath(wxCommandEvent& event)
 {
-#ifdef __WXOSX__
-    // There is a bug in OSX that prevents popup menu from being displayed from dialogs
-    // so we use an alternative way
-    FindInFilesLocationsDlg dlg(this, GetPathsAsArray());
-    if(dlg.ShowModal() == wxID_OK) {
-        wxString paths = wxJoin(dlg.GetLocations(), '\n');
-        DoSetSearchPaths(paths);
-    }
-#else
     // Show a popup menu
     wxMenu menu;
     int firstItem = 8994;
-    menu.Append(firstItem + 6, "Add Folder...");
+    menu.Append(firstItem + 6, _("Add Folder..."));
     menu.AppendSeparator();
-    menu.Append(firstItem + 0, SEARCH_IN_WORKSPACE_FOLDER);
-    menu.Append(firstItem + 1, SEARCH_IN_WORKSPACE);
-    menu.Append(firstItem + 2, SEARCH_IN_PROJECT);
-    menu.Append(firstItem + 3, SEARCH_IN_CURR_FILE_PROJECT);
-    menu.Append(firstItem + 4, SEARCH_IN_CURRENT_FILE);
-    menu.Append(firstItem + 5, SEARCH_IN_OPEN_FILES);
+    menu.Append(firstItem + 0, wxGetTranslation(SEARCH_IN_WORKSPACE_FOLDER));
+    menu.Append(firstItem + 1, wxGetTranslation(SEARCH_IN_WORKSPACE));
+    menu.Append(firstItem + 2, wxGetTranslation(SEARCH_IN_PROJECT));
+    menu.Append(firstItem + 3, wxGetTranslation(SEARCH_IN_CURR_FILE_PROJECT));
+    menu.Append(firstItem + 4, wxGetTranslation(SEARCH_IN_CURRENT_FILE));
+    menu.Append(firstItem + 5, wxGetTranslation(SEARCH_IN_OPEN_FILES));
     menu.AppendSeparator();
-    menu.Append(firstItem + 7, "Add Exclude Pattern");
+    menu.Append(firstItem + 7, _("Add Exclude Pattern"));
 
     std::map<int, wxString> options;
-    options.insert(std::make_pair(firstItem + 0, SEARCH_IN_WORKSPACE_FOLDER));
-    options.insert(std::make_pair(firstItem + 1, SEARCH_IN_WORKSPACE));
-    options.insert(std::make_pair(firstItem + 2, SEARCH_IN_PROJECT));
-    options.insert(std::make_pair(firstItem + 3, SEARCH_IN_CURR_FILE_PROJECT));
-    options.insert(std::make_pair(firstItem + 4, SEARCH_IN_CURRENT_FILE));
-    options.insert(std::make_pair(firstItem + 5, SEARCH_IN_OPEN_FILES));
+    options.insert(std::make_pair(firstItem + 0, wxGetTranslation(SEARCH_IN_WORKSPACE_FOLDER)));
+    options.insert(std::make_pair(firstItem + 1, wxGetTranslation(SEARCH_IN_WORKSPACE)));
+    options.insert(std::make_pair(firstItem + 2, wxGetTranslation(SEARCH_IN_PROJECT)));
+    options.insert(std::make_pair(firstItem + 3, wxGetTranslation(SEARCH_IN_CURR_FILE_PROJECT)));
+    options.insert(std::make_pair(firstItem + 4, wxGetTranslation(SEARCH_IN_CURRENT_FILE)));
+    options.insert(std::make_pair(firstItem + 5, wxGetTranslation(SEARCH_IN_OPEN_FILES)));
 
     // Menu will be shown in client coordinates
     wxRect size = m_btnAddPath->GetSize();
@@ -365,34 +407,33 @@ void FindInFilesDialog::OnAddPath(wxCommandEvent& event)
 
     if(selection == wxID_NONE)
         return;
+
     if(selection == (firstItem + 7)) {
         // Add exclude pattern
-        int lastPos = m_stcPaths->GetLastPosition();
-        wxChar ch = m_stcPaths->GetCharAt(lastPos);
-        if(ch != '\n') {
-            m_stcPaths->SetInsertionPointEnd();
-            m_stcPaths->AddText("\n");
+        wxString current_content = m_comboBoxWhere->GetValue();
+        current_content.Trim();
+        if(!current_content.empty() && !current_content.EndsWith(";")) {
+            current_content << ";";
         }
-        lastPos = m_stcPaths->GetLastPosition();
-        m_stcPaths->SetSelectionStart(lastPos);
-        m_stcPaths->SetSelectionEnd(lastPos);
-        m_stcPaths->SetCurrentPos(lastPos);
-        m_stcPaths->InsertText(lastPos, "-*PATTERN*");
-        int selStart = lastPos + 1;
-        int selEnd = selStart + wxStrlen("*PATTERN*");
-        m_stcPaths->SetSelection(selStart, selEnd);
-        m_stcPaths->CallAfter(&wxStyledTextCtrl::SetFocus);
+
+        int selection_start = current_content.length();
+        current_content << "-*PATTERN*";
+        selection_start += 1; // skip the `-`
+        int selection_end = current_content.length();
+        m_comboBoxWhere->SetValue(current_content);
+        m_comboBoxWhere->GetTextCtrl()->SetSelection(selection_start, selection_end);
+        m_comboBoxWhere->GetTextCtrl()->EnsureCaretVisible();
+        m_comboBoxWhere->GetTextCtrl()->CallAfter(&wxStyledTextCtrl::SetFocus);
 
     } else if(selection == (firstItem + 6)) {
         wxString folder = ::wxDirSelector();
         if(folder.IsEmpty())
             return;
-        DoSetSearchPaths(folder);
+        DoAppendSearchPath(folder);
 
     } else if(options.count(selection)) {
-        DoSetSearchPaths(options.find(selection)->second);
+        DoAppendSearchPath(options.find(selection)->second);
     }
-#endif
 }
 
 int FindInFilesDialog::ShowDialog()
@@ -415,7 +456,13 @@ int FindInFilesDialog::ShowDialog()
     return wxDialog::ShowModal();
 }
 
-void FindInFilesDialog::DoSaveSearchPaths() { m_data.SetSearchPaths(m_stcPaths->GetText()); }
+void FindInFilesDialog::DoSaveSearchPaths()
+{
+    wxArrayString paths;
+    paths = m_comboBoxWhere->GetStrings();
+    paths.Insert(m_comboBoxWhere->GetValue(), 0);
+    m_data.SetWhereOptions(paths);
+}
 
 void FindInFilesDialog::DoSaveOpenFiles()
 {
@@ -467,23 +514,22 @@ size_t FindInFilesDialog::GetSearchFlags()
 
 void FindInFilesDialog::SetSearchPaths(const wxString& paths, bool transient)
 {
-    m_stcPaths->ClearAll();
+    wxArrayString arr = ::wxStringTokenize(paths, ";\n", wxTOKEN_STRTOK);
+    wxString current_value = ::wxJoin(arr, ';');
+    m_comboBoxWhere->SetValue(current_value);
     m_transient = transient;
-    DoSetSearchPaths(paths);
 }
 
-void FindInFilesDialog::DoSetSearchPaths(const wxString& path)
+void FindInFilesDialog::DoAppendSearchPath(const wxString& path)
 {
-    wxString text = m_stcPaths->GetText();
-    text.Replace("\r", ""); // No \r
-    text.Trim().Trim(false);
-    if(!text.IsEmpty()) {
-        text << "\n";
+    wxString current_value = m_comboBoxWhere->GetValue();
+    wxArrayString paths = ::wxStringTokenize(current_value, ";\n", wxTOKEN_STRTOK);
+    if(paths.Index(path) != wxNOT_FOUND) {
+        return;
     }
-    text << path;
-    text.Trim().Trim(false);
-    m_stcPaths->SetText(text);
-    ::clRecalculateSTCHScrollBar(m_stcPaths);
+    paths.Add(path);
+    current_value = ::wxJoin(paths, ';');
+    m_comboBoxWhere->SetValue(current_value);
 }
 
 void FindInFilesDialog::OnReplaceUI(wxUpdateUIEvent& event)
@@ -514,31 +560,51 @@ void FindInFilesDialog::DoAddProjectFiles(const wxString& projectName, wxArraySt
 
 wxArrayString FindInFilesDialog::GetPathsAsArray() const
 {
-    wxString str = m_stcPaths->GetText();
-    str.Replace("\r", "");
-    wxArrayString arr = ::wxStringTokenize(str, "\n", wxTOKEN_STRTOK);
+    wxString str = m_comboBoxWhere->GetValue();
+    wxArrayString arr = ::wxStringTokenize(str, ";", wxTOKEN_STRTOK);
     return arr;
 }
 
+namespace
+{
+wxArrayString GetComboBoxStrings(clComboBox* cb)
+{
+    wxArrayString arr = cb->GetStrings();
+    wxString value = cb->GetValue();
+    int loc = arr.Index(value);
+    if(loc != wxNOT_FOUND) {
+        arr.RemoveAt(loc);
+    }
+    arr.Insert(value, 0);
+    return arr;
+}
+} // namespace
+
 void FindInFilesDialog::BuildFindReplaceData()
 {
-    m_data.SetFlags(GetSearchFlags());
-    m_data.SetFindString(m_findString->GetValue());
-    m_data.SetReplaceString(m_replaceString->GetValue());
-    m_data.SetEncoding(m_choiceEncoding->GetStringSelection());
-    wxString value = m_fileTypes->GetValue();
-    value.Trim().Trim(false);
-
-    wxArrayString masks = m_fileTypes->GetStrings();
-    if(masks.Index(value) == wxNOT_FOUND) {
-        masks.Insert(value, 0);
+    if(m_presetSearch && !m_userChangedRegexManually) {
+        // restore the regex value
+        m_regualrExpression->SetValue(m_oldRegexValue);
     }
 
+    m_data.SetFlags(GetSearchFlags());
+    m_data.SetFindStrings(m_findString->GetStrings());
+    m_data.SetFindString(m_findString->GetValue());
+
+    m_data.SetReplaceStrings(m_replaceString->GetStrings());
+    m_data.SetReplaceString(m_replaceString->GetValue());
+
+    m_data.SetEncoding(m_comboBoxEncoding->GetStringSelection());
+
+    wxArrayString masks = GetComboBoxStrings(m_fileTypes);
+    wxString value = m_fileTypes->GetValue();
+
     m_data.SetSelectedMask(value);
     m_data.SetFileMask(masks);
 
-    // If the search paths were provided by the user, don't store them
-    m_data.SetSearchPaths(m_stcPaths->GetText());
+    // store the "Where"
+    wxArrayString where_arr = GetComboBoxStrings(m_comboBoxWhere);
+    m_data.SetWhereOptions(where_arr);
 }
 
 void FindInFilesDialog::SetFileMask(const wxString& mask)
@@ -552,6 +618,7 @@ void FindInFilesDialog::SetFileMask(const wxString& mask)
         m_fileTypes->SetSelection(where);
     }
 }
+
 void FindInFilesDialog::OnFindEnter(wxCommandEvent& event)
 {
     event.Skip();
@@ -560,7 +627,66 @@ void FindInFilesDialog::OnFindEnter(wxCommandEvent& event)
 
 void FindInFilesDialog::OnReplaceEnter(wxCommandEvent& event) { OnReplace(event); }
 
-void FindInFilesDialog::DoSelectAll()
+void FindInFilesDialog::DoSelectAll() { m_findString->GetTextCtrl()->SelectAll(); }
+
+void FindInFilesDialog::OnATTN(wxCommandEvent& event)
 {
-    m_findString->GetTextCtrl()->SelectAll();
+    m_presetSearch = true;
+    SetPresets();
+}
+
+void FindInFilesDialog::OnBUG(wxCommandEvent& event)
+{
+    m_presetSearch = true;
+    SetPresets();
+}
+
+void FindInFilesDialog::OnFIXME(wxCommandEvent& event)
+{
+    m_presetSearch = true;
+    SetPresets();
+}
+
+void FindInFilesDialog::OnTODO(wxCommandEvent& event)
+{
+    m_presetSearch = true;
+    SetPresets();
+}
+
+void FindInFilesDialog::OnRegex(wxCommandEvent& event)
+{
+    event.Skip();
+    m_userChangedRegexManually = true;
+}
+
+void FindInFilesDialog::SetPresets()
+{
+    wxString pattern;
+    if(m_checkBoxATTN->IsChecked()) {
+        pattern << RE_ATTN << "|";
+    }
+
+    if(m_checkBoxBUG->IsChecked()) {
+        pattern << RE_BUG << "|";
+    }
+
+    if(m_checkBoxFIXME->IsChecked()) {
+        pattern << RE_FIXME << "|";
+    }
+
+    if(m_checkBoxTODO->IsChecked()) {
+        pattern << RE_TODO << "|";
+    }
+
+    if(!pattern.empty()) {
+        // remove the trailing pipe
+        pattern.RemoveLast();
+    }
+
+    m_findString->SetValue(pattern);
+    if(!m_regualrExpression->IsChecked()) {
+        // enable regex
+        m_regualrExpression->SetValue(true);
+        m_presetSearch = true;
+    }
 }
