@@ -70,26 +70,18 @@ WorkspaceTab::WorkspaceTab(wxWindow* parent, const wxString& caption)
 
     CreateGUIControls();
     ConnectEvents();
-    m_themeHelper = NULL; // new ThemeHandlerHelper(this);
     SetDropTarget(new clFileOrFolderDropTarget(this));
     Bind(wxEVT_DND_FOLDER_DROPPED, &WorkspaceTab::OnFolderDropped, this);
-    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_BUILD_CONFIG_CHANGED, &WorkspaceTab::OnConfigChanged, this);
 
     m_panelCxx->Bind(wxEVT_PAINT, [&](wxPaintEvent& e) {
         wxAutoBufferedPaintDC dc(m_panelCxx);
-        dc.SetBrush(m_bgColour);
-        dc.SetPen(m_bgColour);
+        dc.SetBrush(clSystemSettings::GetDefaultPanelColour());
+        dc.SetPen(clSystemSettings::GetDefaultPanelColour());
         dc.DrawRectangle(m_panelCxx->GetClientRect());
     });
 
-    m_bgColour = DrawingUtils::GetPanelBgColour();
-    EventNotifier::Get()->Bind(wxEVT_CMD_COLOURS_FONTS_UPDATED, [&](clCommandEvent& event) {
+    EventNotifier::Get()->Bind(wxEVT_SYS_COLOURS_CHANGED, [&](clCommandEvent& event) {
         event.Skip();
-        bool useCustomColour = clConfig::Get().Read("UseCustomBaseColour", false);
-        m_bgColour = DrawingUtils::GetPanelBgColour();
-        if(useCustomColour) {
-            m_bgColour = clConfig::Get().Read("BaseColour", m_bgColour);
-        }
         Refresh();
         m_panelCxx->Refresh();
     });
@@ -99,16 +91,13 @@ WorkspaceTab::WorkspaceTab(wxWindow* parent, const wxString& caption)
 
 WorkspaceTab::~WorkspaceTab()
 {
-    wxDELETE(m_themeHelper);
     wxTheApp->Disconnect(XRCID("show_in_workspace"), wxEVT_COMMAND_MENU_SELECTED,
                          wxCommandEventHandler(WorkspaceTab::OnShowFile), NULL, this);
     wxTheApp->Disconnect(XRCID("show_in_workspace"), wxEVT_UPDATE_UI,
                          wxUpdateUIEventHandler(WorkspaceTab::OnShowFileUI), NULL, this);
 
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceLoaded),
-                                     NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceClosed),
-                                     NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_LOADED, &WorkspaceTab::OnWorkspaceLoaded, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &WorkspaceTab::OnWorkspaceClosed, this);
     EventNotifier::Get()->Disconnect(wxEVT_PROJ_ADDED, clCommandEventHandler(WorkspaceTab::OnProjectAdded), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_PROJ_REMOVED, clCommandEventHandler(WorkspaceTab::OnProjectRemoved), NULL,
                                      this);
@@ -116,17 +105,10 @@ WorkspaceTab::~WorkspaceTab()
                                      wxCommandEventHandler(WorkspaceTab::OnActiveEditorChanged), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_EDITOR_CLOSING, wxCommandEventHandler(WorkspaceTab::OnEditorClosing), NULL,
                                      this);
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_CONFIG_CHANGED,
-                                     wxCommandEventHandler(WorkspaceTab::OnWorkspaceConfig), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_ACTIVE_PROJECT_CHANGED,
-                                     clProjectSettingsEventHandler(WorkspaceTab::OnActiveProjectChanged), NULL, this);
 
-    wxTheApp->Disconnect(XRCID("configuration_manager"), wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(WorkspaceTab::OnConfigurationManager), NULL, this);
     wxTheApp->Disconnect(XRCID("configuration_manager"), wxEVT_UPDATE_UI,
                          wxUpdateUIEventHandler(WorkspaceTab::OnProjectSettingsUI), NULL, this);
 
-    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_BUILD_CONFIG_CHANGED, &WorkspaceTab::OnConfigChanged, this);
     EventNotifier::Get()->Unbind(wxEVT_BUILD_STARTED, &WorkspaceTab::OnBuildStarted, this);
     EventNotifier::Get()->Unbind(wxEVT_BUILD_ENDED, &WorkspaceTab::OnBuildEnded, this);
     EventNotifier::Get()->Unbind(wxEVT_PROGRAM_STARTED, &WorkspaceTab::OnProgramStarted, this);
@@ -159,19 +141,18 @@ void WorkspaceTab::CreateGUIControls()
     m_view->AddPage(new DefaultWorkspacePage(m_simpleBook), _("Default"));
     m_view->SelectPage(_("Default"));
     m_view->SetDefaultPage(_("Default"));
-    BitmapLoader* bmps = clGetManager()->GetStdIcons();
-    m_toolbar580->AddTool(XRCID("ID_TOOL_LINK_EDITOR"), _("Link Editor"), bmps->LoadBitmap("link_editor"), "",
-                          wxITEM_CHECK);
-    m_toolbar580->AddTool(XRCID("ID_TOOL_COLLAPSE_ALL"), _("Collapse All"), bmps->LoadBitmap("fold"));
-    m_toolbar580->AddTool(XRCID("ID_TOOL_GOTO_ACTIVE_PROJECT"), _("Goto Active Project"), bmps->LoadBitmap("home"));
+    auto images = m_toolbar580->GetBitmapsCreateIfNeeded();
+    m_toolbar580->AddTool(XRCID("ID_TOOL_LINK_EDITOR"), _("Link Editor"), images->Add("link_editor"), "", wxITEM_CHECK);
+    m_toolbar580->AddTool(XRCID("ID_TOOL_COLLAPSE_ALL"), _("Collapse All"), images->Add("fold"));
+    m_toolbar580->AddTool(XRCID("ID_TOOL_GOTO_ACTIVE_PROJECT"), _("Goto Active Project"), images->Add("home"));
     m_toolbar580->AddTool(XRCID("ID_TOOL_ACTIVE_PROJECT_SETTINGS"),
                           _("Open selected project settings. If there is no project selected, open the parent project "
                             "of the selected item in the tree"),
-                          bmps->LoadBitmap("cog"));
+                          images->Add("cog"));
     m_toolbar580->AddSpacer();
-    m_toolbar580->AddTool(XRCID("ID_BUILD_PROJECT"), _("Build Active Project"), bmps->LoadBitmap("build"),
+    m_toolbar580->AddTool(XRCID("ID_BUILD_PROJECT"), _("Build Active Project"), images->Add("build"),
                           _("Build Active Project"), wxITEM_DROPDOWN);
-    m_toolbar580->AddTool(XRCID("ID_EXECUTE_NO_DEBUG"), _("Run Active Project"), bmps->LoadBitmap("execute"),
+    m_toolbar580->AddTool(XRCID("ID_EXECUTE_NO_DEBUG"), _("Run Active Project"), images->Add("execute"),
                           _("Run Active Project"));
     m_toolbar580->Realize();
 }
@@ -203,10 +184,9 @@ void WorkspaceTab::ConnectEvents()
                       wxCommandEventHandler(WorkspaceTab::OnShowFile), NULL, this);
     wxTheApp->Connect(XRCID("show_in_workspace"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(WorkspaceTab::OnShowFileUI),
                       NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceLoaded), NULL,
-                                  this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceClosed), NULL,
-                                  this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_LOADED, &WorkspaceTab::OnWorkspaceLoaded, this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &WorkspaceTab::OnWorkspaceClosed, this);
+
     EventNotifier::Get()->Connect(wxEVT_PROJ_ADDED, clCommandEventHandler(WorkspaceTab::OnProjectAdded), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_PROJ_REMOVED, clCommandEventHandler(WorkspaceTab::OnProjectRemoved), NULL,
                                   this);
@@ -214,12 +194,6 @@ void WorkspaceTab::ConnectEvents()
                                   wxCommandEventHandler(WorkspaceTab::OnActiveEditorChanged), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_EDITOR_CLOSING, wxCommandEventHandler(WorkspaceTab::OnEditorClosing), NULL,
                                   this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CONFIG_CHANGED,
-                                  wxCommandEventHandler(WorkspaceTab::OnWorkspaceConfig), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_ACTIVE_PROJECT_CHANGED,
-                                  clProjectSettingsEventHandler(WorkspaceTab::OnActiveProjectChanged), NULL, this);
-    wxTheApp->Connect(XRCID("configuration_manager"), wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(WorkspaceTab::OnConfigurationManager), NULL, this);
     wxTheApp->Connect(XRCID("configuration_manager"), wxEVT_UPDATE_UI,
                       wxUpdateUIEventHandler(WorkspaceTab::OnProjectSettingsUI), NULL, this);
     m_toolbar580->Bind(wxEVT_TOOL, &WorkspaceTab::OnCollapseAll, this, XRCID("ID_TOOL_COLLAPSE_ALL"));
@@ -331,32 +305,19 @@ void WorkspaceTab::OnActiveEditorChanged(wxCommandEvent& e)
         MainBook* mainbook = clMainFrame::Get()->GetMainBook();
         clEditor* editor = mainbook->GetActiveEditor();
         if(editor && !editor->GetProject().IsEmpty()) {
-            m_fileView->ExpandToPath(editor->GetProject(), editor->GetFileName());
-        }
-
-        Notebook* book = clMainFrame::Get()->GetWorkspacePane()->GetNotebook();
-        if(book) {
-            size_t index = book->GetPageIndex("wxCrafter");
-            if(index == (size_t)book->GetSelection()) {
-                book->SetSelection(0); // The most likely to be wanted
-            }
+            m_fileView->CallAfter(&FileViewTree::ExpandToPath, editor->GetProject(), editor->GetFileName());
         }
     }
 }
 
-void WorkspaceTab::OnWorkspaceLoaded(wxCommandEvent& e)
+void WorkspaceTab::OnWorkspaceLoaded(clWorkspaceEvent& e)
 {
     e.Skip();
     if(ManagerST::Get()->IsWorkspaceOpen()) {
-        m_configChangeCtrl->Enable(true);
-        DoWorkspaceConfig();
-        DoUpdateChoiceWithProjects();
-
         // Tree construction
         m_fileView->BuildTree();
         CallAfter(&WorkspaceTab::DoGoHome);
         SendCmdEvent(wxEVT_FILE_VIEW_INIT_DONE);
-
         // Load the C++ pinned projects list
         LoadCxxPinnedProjects();
     }
@@ -364,18 +325,15 @@ void WorkspaceTab::OnWorkspaceLoaded(wxCommandEvent& e)
 
 void WorkspaceTab::OnEditorClosing(wxCommandEvent& e) { e.Skip(); }
 
-void WorkspaceTab::OnWorkspaceClosed(wxCommandEvent& e)
+void WorkspaceTab::OnWorkspaceClosed(clWorkspaceEvent& e)
 {
     e.Skip();
-    m_configChangeCtrl->Clear();
-    m_configChangeCtrl->Enable(false);
     m_fileView->DeleteAllItems();
 
     // Clear the pinned projects view
     m_dvListCtrlPinnedProjects->DeleteAllItems();
     SaveCxxPinnedProjects();
     m_cxxPinnedProjects.clear();
-
     SendCmdEvent(wxEVT_FILE_VIEW_INIT_DONE);
 }
 
@@ -387,7 +345,6 @@ void WorkspaceTab::OnProjectAdded(clCommandEvent& e)
     if(!projName.IsEmpty()) {
         m_fileView->ExpandToPath(projName, wxFileName());
     }
-    DoUpdateChoiceWithProjects();
     SendCmdEvent(wxEVT_FILE_VIEW_REFRESHED);
 }
 
@@ -396,7 +353,6 @@ void WorkspaceTab::OnProjectRemoved(clCommandEvent& e)
     e.Skip();
     m_fileView->BuildTree();
     CallAfter(&WorkspaceTab::DoGoHome);
-    DoUpdateChoiceWithProjects();
     SendCmdEvent(wxEVT_FILE_VIEW_REFRESHED);
 }
 
@@ -407,53 +363,12 @@ struct wxStringSorter {
     }
 };
 
-void WorkspaceTab::DoWorkspaceConfig()
-{
-    // Update the workspace configuration
-    BuildMatrixPtr matrix = clCxxWorkspaceST::Get()->GetBuildMatrix();
-    std::list<WorkspaceConfigurationPtr> confs = matrix->GetConfigurations();
-
-    confs.sort(wxStringSorter());
-    wxArrayString configurations;
-    std::for_each(confs.begin(), confs.end(),
-                  [&](WorkspaceConfigurationPtr conf) { configurations.push_back(conf->GetName()); });
-
-    m_configChangeCtrl->SetConfigurations(configurations);
-    wxString activeConfig = configurations.IsEmpty() ? "" : matrix->GetSelectedConfigurationName();
-    m_configChangeCtrl->SetActiveConfiguration(activeConfig);
-
-    clMainFrame::Get()->SelectBestEnvSet();
-}
-
-void WorkspaceTab::OnWorkspaceConfig(wxCommandEvent& e)
-{
-    e.Skip();
-    DoWorkspaceConfig();
-}
-
-void WorkspaceTab::OnConfigurationManager(wxCommandEvent& e)
-{
-    wxUnusedVar(e);
-    ConfigurationManagerDlg dlg(EventNotifier::Get()->TopFrame());
-    dlg.ShowModal();
-
-    BuildMatrixPtr matrix = ManagerST::Get()->GetWorkspaceBuildMatrix();
-    m_configChangeCtrl->SetActiveConfiguration(matrix->GetSelectedConfigurationName());
-}
-
 void WorkspaceTab::OnLinkEditorUI(wxUpdateUIEvent& event)
 {
     event.Enable(ManagerST::Get()->IsWorkspaceOpen());
     event.Check(m_isLinkedToEditor);
 }
 
-void WorkspaceTab::DoUpdateChoiceWithProjects()
-{
-    if(clCxxWorkspaceST::Get()->IsOpen()) {
-        m_configChangeCtrl->SetActiveProject(ManagerST::Get()->GetActiveProjectName());
-    }
-}
-
 void WorkspaceTab::OnWorkspaceOpenUI(wxUpdateUIEvent& event) { event.Enable(ManagerST::Get()->IsWorkspaceOpen()); }
 
 void WorkspaceTab::OpenProjectSettings(const wxString& project)
@@ -504,14 +419,6 @@ void WorkspaceTab::OpenProjectSettings(const wxString& project)
 
 void WorkspaceTab::ProjectSettingsDlgClosed() { m_dlg = NULL; }
 
-void WorkspaceTab::OnActiveProjectChanged(clProjectSettingsEvent& e)
-{
-    e.Skip();
-
-    // Update the choice control
-    m_configChangeCtrl->SetActiveProject(e.GetProjectName());
-}
-
 void WorkspaceTab::DoGoHome()
 {
     wxString activeProject = ManagerST::Get()->GetActiveProjectName();
@@ -530,47 +437,17 @@ void WorkspaceTab::DoGoHome()
     // ManagerST::Get()->ShowWorkspacePane(m_caption);
 }
 
-void WorkspaceTab::DoConfigChanged(const wxString& newConfigName)
-{
-    wxBusyCursor bc;
-    BuildMatrixPtr matrix = ManagerST::Get()->GetWorkspaceBuildMatrix();
-    matrix->SetSelectedConfigurationName(newConfigName);
-    ManagerST::Get()->SetWorkspaceBuildMatrix(matrix);
-
-    // Set the focus to the active editor if any
-    clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
-    if(editor) {
-        editor->SetActive();
-    }
-
-    ManagerST::Get()->UpdateParserPaths(true);
-}
-
 void WorkspaceTab::OnFolderDropped(clCommandEvent& event)
 {
     // pass it on to the tree view
     m_fileView->CallAfter(&FileViewTree::FolderDropped, event.GetStrings());
 }
 
-void WorkspaceTab::OnConfigChanged(clCommandEvent& e)
-{
-    e.Skip();
-    wxString selection = e.GetString();
-    if(selection == OPEN_CONFIG_MGR_STR) {
-        e.Skip(false);
-        wxCommandEvent e(wxEVT_MENU, XRCID("configuration_manager"));
-        e.SetEventObject(this);
-        ProcessEvent(e);
-        return;
-    }
-    DoConfigChanged(selection);
-}
-
 void WorkspaceTab::OnPaint(wxPaintEvent& event)
 {
     wxAutoBufferedPaintDC dc(this);
-    dc.SetBrush(m_bgColour);
-    dc.SetPen(m_bgColour);
+    dc.SetBrush(clSystemSettings::GetDefaultPanelColour());
+    dc.SetPen(clSystemSettings::GetDefaultPanelColour());
     dc.DrawRectangle(GetClientRect());
 }
 
@@ -684,8 +561,9 @@ void WorkspaceTab::OnBuildStarted(clBuildEvent& event)
     event.Skip();
     m_buildInProgress = true;
     auto button = m_toolbar580->FindById(XRCID("ID_BUILD_PROJECT"));
+    auto images = m_toolbar580->GetBitmapsCreateIfNeeded();
     if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("stop"));
+        button->SetBitmapIndex(images->Add("stop"));
         button->SetLabel(_("Stop Current Build"));
         m_toolbar580->Refresh();
     }
@@ -696,8 +574,9 @@ void WorkspaceTab::OnBuildEnded(clBuildEvent& event)
     event.Skip();
     m_buildInProgress = false;
     auto button = m_toolbar580->FindById(XRCID("ID_BUILD_PROJECT"));
+    auto images = m_toolbar580->GetBitmapsCreateIfNeeded();
     if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("build"));
+        button->SetBitmapIndex(images->Add("build"));
         button->SetLabel(_("Build Active Project"));
         m_toolbar580->Refresh();
     }
@@ -746,8 +625,9 @@ void WorkspaceTab::OnProgramStarted(clExecuteEvent& event)
     event.Skip();
     m_runInProgress = true;
     auto button = m_toolbar580->FindById(XRCID("ID_EXECUTE_NO_DEBUG"));
+    auto images = m_toolbar580->GetBitmapsCreateIfNeeded();
     if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("stop"));
+        button->SetBitmapIndex(images->Add("stop"));
         button->SetLabel(_("Stop running program"));
         m_toolbar580->Refresh();
     }
@@ -758,8 +638,9 @@ void WorkspaceTab::OnProgramStopped(clExecuteEvent& event)
     event.Skip();
     m_runInProgress = false;
     auto button = m_toolbar580->FindById(XRCID("ID_EXECUTE_NO_DEBUG"));
+    auto images = m_toolbar580->GetBitmapsCreateIfNeeded();
     if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("execute"));
+        button->SetBitmapIndex(images->Add("execute"));
         button->SetLabel(_("Run active project"));
         m_toolbar580->Refresh();
     }
