@@ -26,18 +26,19 @@
 #ifndef __SymbolView__
 #define __SymbolView__
 
+#include "cl_command_event.h"
+#include "dockablepane.h"
+#include "globals.h"
+#include "outline_tab.h"
+#include "plugin.h"
+#include "windowstack.h"
+
 #include <map>
 #include <queue>
 #include <wx/choice.h>
-#include "outline_tab.h"
 #include <wx/imaglist.h>
-#include <wx/treectrl.h>
 #include <wx/splitter.h>
-#include "plugin.h"
-#include "dockablepane.h"
-#include "windowstack.h"
-#include "globals.h"
-#include "cl_command_event.h"
+#include <wx/treectrl.h>
 
 class SymbolViewPlugin : public IPlugin
 {
@@ -46,9 +47,7 @@ protected:
 
 protected:
     bool IsPaneDetached();
-    int DoFindTabIndex();
     void OnToggleTab(clCommandEvent& event);
-    void OnPageChanged(wxBookCtrlEvent& e);
 
 public:
     //--------------------------------------------
