@@ -22,28 +22,30 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "event_notifier.h"
-#include "fileextmanager.h"
-#include "project.h"
-#include <wx/app.h>
-#include <wx/msgdlg.h>
-
-#include "build_settings_config.h"
 #include "builder_gnumake.h"
+
+#include "StringUtils.h"
+#include "build_settings_config.h"
 #include "buildmanager.h"
 #include "cl_command_event.h"
 #include "configuration_mapping.h"
 #include "dirsaver.h"
 #include "editor_config.h"
 #include "environmentconfig.h"
+#include "event_notifier.h"
 #include "evnvarlist.h"
 #include "file_logger.h"
+#include "fileextmanager.h"
 #include "globals.h"
 #include "macromanager.h"
 #include "macros.h"
+#include "project.h"
 #include "wx/sstream.h"
 #include "wx/tokenzr.h"
+
 #include <algorithm>
+#include <wx/app.h>
+#include <wx/msgdlg.h>
 #include <wx/stopwatch.h>
 
 static bool OS_WINDOWS = wxGetOsVersion() & wxOS_WINDOWS ? true : false;
@@ -55,7 +57,9 @@ static wxString GetMakeDirCmd(BuildConfigPtr bldConf, const wxString& relPath =
 
     intermediateDirectory.Replace(wxT("\\"), wxT("/"));
     intermediateDirectory.Trim().Trim(false);
-    if(intermediateDirectory.StartsWith(wxT("./")) && relativePath == wxT("./")) { relativePath.Clear(); }
+    if(intermediateDirectory.StartsWith(wxT("./")) && relativePath == wxT("./")) {
+        relativePath.Clear();
+    }
 
     if(intermediateDirectory.StartsWith(wxT("./")) && relativePath.IsEmpty() == false) {
         intermediateDirectory = intermediateDirectory.Mid(2);
@@ -91,7 +95,9 @@ BuilderGNUMakeClassic::~BuilderGNUMakeClassic() {}
 bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& confToBuild, const wxString& arguments,
                                    bool isProjectOnly, bool force, wxString& errMsg)
 {
-    if(project.IsEmpty()) { return false; }
+    if(project.IsEmpty()) {
+        return false;
+    }
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
     if(!proj) {
         errMsg << _("Cant open project '") << project << wxT("'");
@@ -128,13 +134,17 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
     for(size_t i = 0; i < depsArr.GetCount(); ++i) {
         wxString errmsg;
         ProjectPtr dependProj = clCxxWorkspaceST::Get()->FindProjectByName(depsArr.Item(i), errmsg);
-        if(!dependProj) { continue; }
+        if(!dependProj) {
+            continue;
+        }
 
         wxString projectSelConf = clCxxWorkspaceST::Get()->GetBuildMatrix()->GetProjectSelectedConf(
             clCxxWorkspaceST::Get()->GetBuildMatrix()->GetSelectedConfigurationName(), dependProj->GetName());
         BuildConfigPtr dependProjbldConf =
             clCxxWorkspaceST::Get()->GetProjBuildConf(dependProj->GetName(), projectSelConf);
-        if(dependProjbldConf && dependProjbldConf->IsProjectEnabled()) { updatedDepsArr.Add(depsArr.Item(i)); }
+        if(dependProjbldConf && dependProjbldConf->IsProjectEnabled()) {
+            updatedDepsArr.Add(depsArr.Item(i));
+        }
     }
 
     // Update the dependencies with the correct list
@@ -173,11 +183,14 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
         bool modified = proj->IsModified();
 
         // Update the dependencies only if needed
-        if(settingsChanged) proj->SetDependencies(depsArr, bld_conf_name);
+        if(settingsChanged)
+            proj->SetDependencies(depsArr, bld_conf_name);
 
         // the set settings functions marks the project as 'modified' this causes
         // an unneeded makefile generation if the settings was not really modified
-        if(!modified && !settingsChanged) { proj->SetModified(false); }
+        if(!modified && !settingsChanged) {
+            proj->SetModified(false);
+        }
     }
 
     wxString fn;
@@ -204,24 +217,30 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
         for(size_t i = 0; i < depsArr.GetCount(); ++i) {
             bool isCustom(false);
             ProjectPtr dependProj = clCxxWorkspaceST::Get()->FindProjectByName(depsArr.Item(i), errMsg);
-            if(!dependProj) { continue; }
+            if(!dependProj) {
+                continue;
+            }
 
             wxString projectSelConf = matrix->GetProjectSelectedConf(workspaceSelConf, dependProj->GetName());
             BuildConfigPtr dependProjbldConf =
                 clCxxWorkspaceST::Get()->GetProjBuildConf(dependProj->GetName(), projectSelConf);
-            if(dependProjbldConf && dependProjbldConf->IsCustomBuild()) { isCustom = true; }
+            if(dependProjbldConf && dependProjbldConf->IsCustomBuild()) {
+                isCustom = true;
+            }
 
             // incase we manually specified the configuration to be built, set the project
             // as modified, so on next attempt to build it, CodeLite will sync the configuration
-            if(confToBuild.IsEmpty() == false) { dependProj->SetModified(true); }
+            if(confToBuild.IsEmpty() == false) {
+                dependProj->SetModified(true);
+            }
 
             if(!dependProjbldConf->IsProjectEnabled()) {
                 // Ignore disabled projects
                 continue;
             }
 
-            text << wxT("\t@echo \"") << wxGetTranslation(BUILD_PROJECT_PREFIX) << dependProj->GetName() << wxT(" - ")
-                 << projectSelConf << wxT(" ]----------\"\n");
+            text << wxT("\t@echo \"") << BUILD_PROJECT_PREFIX << dependProj->GetName() << wxT(" - ") << projectSelConf
+                 << wxT(" ]----------\"\n");
             // make the paths relative, if it's sensible to do so
             wxFileName fn(dependProj->GetFileName());
             MakeRelativeIfSensible(fn, wspfile.GetPath());
@@ -256,7 +275,9 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
 
                 build_cmd.Trim().Trim(false);
 
-                if(build_cmd.empty()) { build_cmd << wxT("@echo Project has no custom build command!"); }
+                if(build_cmd.empty()) {
+                    build_cmd << wxT("@echo Project has no custom build command!");
+                }
 
                 // if a working directory is provided apply it, otherwise use the project
                 // path
@@ -287,7 +308,9 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
 
     // incase we manually specified the configuration to be built, set the project
     // as modified, so on next attempt to build it, CodeLite will sync the configuration
-    if(confToBuild.IsEmpty() == false) { proj->SetModified(true); }
+    if(confToBuild.IsEmpty() == false) {
+        proj->SetModified(true);
+    }
 
     wxString projectSelConf = matrix->GetProjectSelectedConf(workspaceSelConf, project);
     if(isProjectOnly && confToBuild.IsEmpty() == false) {
@@ -296,7 +319,7 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
         projectSelConf = confToBuild;
     }
 
-    text << wxT("\t@echo \"") << wxGetTranslation(BUILD_PROJECT_PREFIX) << project << wxT(" - ") << projectSelConf
+    text << wxT("\t@echo \"") << BUILD_PROJECT_PREFIX << project << wxT(" - ") << projectSelConf
          << wxT(" ]----------\"\n");
 
     // make the paths relative, if it's sensible to do so
@@ -331,10 +354,12 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
 
             ProjectPtr dependProj = clCxxWorkspaceST::Get()->FindProjectByName(depsArr.Item(i), errMsg);
             // Missing dependencies project? just skip it
-            if(!dependProj) { continue; }
+            if(!dependProj) {
+                continue;
+            }
 
-            text << wxT("\t@echo \"") << wxGetTranslation(CLEAN_PROJECT_PREFIX) << dependProj->GetName() << wxT(" - ")
-                 << projectSelConf << wxT(" ]----------\"\n");
+            text << wxT("\t@echo \"") << CLEAN_PROJECT_PREFIX << dependProj->GetName() << wxT(" - ") << projectSelConf
+                 << wxT(" ]----------\"\n");
 
             // make the paths relative
             wxFileName fn(dependProj->GetFileName());
@@ -344,7 +369,9 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
             // of the geenrated makefile
             BuildConfigPtr dependProjbldConf =
                 clCxxWorkspaceST::Get()->GetProjBuildConf(dependProj->GetName(), projectSelConf);
-            if(dependProjbldConf && dependProjbldConf->IsCustomBuild()) { isCustom = true; }
+            if(dependProjbldConf && dependProjbldConf->IsCustomBuild()) {
+                isCustom = true;
+            }
 
             // if we are using custom build command, invoke it instead of calling the generated makefile
             wxString pname = dependProj->GetName();
@@ -380,7 +407,9 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
                 wxString customWdCmd;
 
                 clean_cmd.Trim().Trim(false);
-                if(clean_cmd.empty()) { clean_cmd << wxT("@echo Project has no custom clean command!"); }
+                if(clean_cmd.empty()) {
+                    clean_cmd << wxT("@echo Project has no custom clean command!");
+                }
 
                 // if a working directory is provided apply it, otherwise use the project
                 // path
@@ -403,7 +432,7 @@ bool BuilderGNUMakeClassic::Export(const wxString& project, const wxString& conf
         projectSelConf = confToBuild;
     }
 
-    text << wxT("\t@echo \"") << wxGetTranslation(CLEAN_PROJECT_PREFIX) << project << wxT(" - ") << projectSelConf
+    text << wxT("\t@echo \"") << CLEAN_PROJECT_PREFIX << project << wxT(" - ") << projectSelConf
          << wxT(" ]----------\"\n");
     if(isPluginGeneratedMakefile) {
 
@@ -453,11 +482,15 @@ void BuilderGNUMakeClassic::GenerateMakefile(ProjectPtr proj, const wxString& co
     }
 
     ProjectSettingsPtr settings = proj->GetSettings();
-    if(!settings) { return; }
+    if(!settings) {
+        return;
+    }
 
     // get the selected build configuration for this project
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(proj->GetName(), confToBuild);
-    if(!bldConf) { return; }
+    if(!bldConf) {
+        return;
+    }
 
     wxString path = proj->GetFileName().GetPath();
 
@@ -472,7 +505,9 @@ void BuilderGNUMakeClassic::GenerateMakefile(ProjectPtr proj, const wxString& co
     // skip the next test if the makefile does not exist
     if(wxFileName::FileExists(fn)) {
         if(!force) {
-            if(proj->IsModified() == false) { return; }
+            if(proj->IsModified() == false) {
+                return;
+            }
         }
     }
 
@@ -592,7 +627,8 @@ void BuilderGNUMakeClassic::CreateSrcList(ProjectPtr proj, const wxString& confT
     for(size_t i = 0; i < files.size(); i++) {
 
         // is this a valid file?
-        if(!cmp->GetCmpFileType(files[i].GetExt(), ft)) continue;
+        if(!cmp->GetCmpFileType(files[i].GetExt(), ft))
+            continue;
 
         if(ft.kind == Compiler::CmpFileKindResource) {
 #ifndef __WXMSW__
@@ -608,7 +644,9 @@ void BuilderGNUMakeClassic::CreateSrcList(ProjectPtr proj, const wxString& confT
         // Compiler::CmpFileKindSource , Compiler::CmpFileKindResource file
         text << relPath << files[i].GetFullName() << wxT(" ");
 
-        if(counter % 10 == 0) { text << wxT("\\\n\t"); }
+        if(counter % 10 == 0) {
+            text << wxT("\\\n\t");
+        }
         counter++;
     }
     text << wxT("\n\n");
@@ -668,15 +706,20 @@ void BuilderGNUMakeClassic::CreateObjectList(ProjectPtr proj, const wxString& co
         }
 
         // is this a valid file?
-        if(!cmp->GetCmpFileType(files[i].GetExt(), ft)) continue;
+        if(!cmp->GetCmpFileType(files[i].GetExt(), ft))
+            continue;
 
-        if(ft.kind == Compiler::CmpFileKindResource && !OS_WINDOWS) { continue; }
+        if(ft.kind == Compiler::CmpFileKindResource && !OS_WINDOWS) {
+            continue;
+        }
 
         wxString objPrefix = DoGetTargetPrefix(files.at(i), projectPath, cmp);
         curChunk << wxT("$(IntermediateDirectory)/") << objPrefix << files[i].GetFullName() << wxT("$(ObjectSuffix) ");
 
         // for readability, break every 10 objects and start a new line
-        if(counter % 10 == 0) { curChunk << wxT("\\\n\t"); }
+        if(counter % 10 == 0) {
+            curChunk << wxT("\\\n\t");
+        }
         counter++;
         numOfObjectsInCurrentChunk++;
     }
@@ -793,7 +836,9 @@ void BuilderGNUMakeClassic::CreateFileTargets(ProjectPtr proj, const wxString& c
                 text << objectName << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
 
                 wxString cmpOptions(wxT("$(CXXFLAGS) $(IncludePCH)"));
-                if(isCFile) { cmpOptions = wxT("$(CFLAGS)"); }
+                if(isCFile) {
+                    cmpOptions = wxT("$(CFLAGS)");
+                }
 
                 // set the source file we want to compile
                 wxString source_file_to_compile = rel_paths.at(i).GetFullPath(wxPATH_UNIX);
@@ -834,10 +879,14 @@ void BuilderGNUMakeClassic::CreateFileTargets(ProjectPtr proj, const wxString& c
 static wxString GetIntermediateFolder(BuildConfigPtr bldConf)
 {
     wxString IntermediateDirectory = bldConf->GetIntermediateDirectory();
-    if(IntermediateDirectory == "/" || IntermediateDirectory.IsEmpty()) { return wxEmptyString; }
+    if(IntermediateDirectory == "/" || IntermediateDirectory.IsEmpty()) {
+        return wxEmptyString;
+    }
 
     // not empty and does not equal to "/"
-    if(!IntermediateDirectory.EndsWith("/")) { IntermediateDirectory.Append('/'); }
+    if(!IntermediateDirectory.EndsWith("/")) {
+        IntermediateDirectory.Append('/');
+    }
     return IntermediateDirectory;
 }
 
@@ -868,7 +917,9 @@ void BuilderGNUMakeClassic::CreateCleanTargets(ProjectPtr proj, const wxString&
         wxString pchFile = bldConf->GetPrecompiledHeader();
         pchFile.Trim().Trim(false);
 
-        if(pchFile.IsEmpty() == false) { text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n"); }
+        if(pchFile.IsEmpty() == false && (bldConf->GetPCHFlagsPolicy() != BuildConfig::kPCHJustInclude)) {
+            text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n");
+        }
 
     } else if(OS_WINDOWS) {
         text << wxT("\t") << wxT("$(RM) ") << imd << "*$(ObjectSuffix)" << wxT("\n");
@@ -890,7 +941,9 @@ void BuilderGNUMakeClassic::CreateCleanTargets(ProjectPtr proj, const wxString&
         wxString pchFile = bldConf->GetPrecompiledHeader();
         pchFile.Trim().Trim(false);
 
-        if(pchFile.IsEmpty() == false) { text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n"); }
+        if(pchFile.IsEmpty() == false && (bldConf->GetPCHFlagsPolicy() != BuildConfig::kPCHJustInclude)) {
+            text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n");
+        }
     } else {
         text << wxT("\t") << wxT("$(RM) ") << imd << "*$(ObjectSuffix)" << wxT("\n");
         text << wxT("\t") << wxT("$(RM) ") << imd << "*$(DependSuffix)" << wxT("\n");
@@ -904,7 +957,9 @@ void BuilderGNUMakeClassic::CreateCleanTargets(ProjectPtr proj, const wxString&
         wxString pchFile = bldConf->GetPrecompiledHeader();
         pchFile.Trim().Trim(false);
 
-        if(pchFile.IsEmpty() == false) { text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n"); }
+        if(pchFile.IsEmpty() == false && (bldConf->GetPCHFlagsPolicy() != BuildConfig::kPCHJustInclude)) {
+            text << wxT("\t") << wxT("$(RM) ") << pchFile << wxT(".gch") << wxT("\n");
+        }
     }
     text << wxT("\n\n");
 }
@@ -952,7 +1007,8 @@ void BuilderGNUMakeClassic::CreateLinkTargets(const wxString& type, BuildConfigP
         text << wxT("$(OutputFile)\n\n");
 
         text << wxT("$(OutputFile): $(IntermediateDirectory)/.d ");
-        if(extraDeps.IsEmpty() == false) text << extraDeps;
+        if(extraDeps.IsEmpty() == false)
+            text << extraDeps;
 
         text << wxT("$(Objects) \n");
         targetName = wxT("$(IntermediateDirectory)/.d");
@@ -967,7 +1023,9 @@ void BuilderGNUMakeClassic::CreateLinkTargets(const wxString& type, BuildConfigP
         CreateTargets(type, bldConf, text, projName);
 
         if(type == PROJECT_TYPE_EXECUTABLE || type == PROJECT_TYPE_DYNAMIC_LIBRARY) {
-            if(depsRules.IsEmpty() == false) { text << wxT("\n") << depsRules << wxT("\n"); }
+            if(depsRules.IsEmpty() == false) {
+                text << wxT("\n") << depsRules << wxT("\n");
+            }
         }
     }
 }
@@ -985,7 +1043,8 @@ void BuilderGNUMakeClassic::CreateTargets(const wxString& type, BuildConfigPtr b
     // $(Objects) variable (to be used with the @<file-name> option of the LD
     for(size_t i = 0; i < m_objectChunks; ++i) {
         wxString oper = ">>";
-        if(i == 0) oper = " >";
+        if(i == 0)
+            oper = " >";
 
         text << "\t@echo $(Objects" << i << ") " << oper << " $(ObjectsFileList)\n";
     }
@@ -1009,7 +1068,8 @@ void BuilderGNUMakeClassic::CreateTargets(const wxString& type, BuildConfigPtr b
 
 void BuilderGNUMakeClassic::CreatePostBuildEvents(ProjectPtr proj, BuildConfigPtr bldConf, wxString& text)
 {
-    if(!HasPostbuildCommands(bldConf)) return;
+    if(!HasPostbuildCommands(bldConf))
+        return;
 
     // generate postbuild commands
     BuildCommandList cmds;
@@ -1033,9 +1093,13 @@ void BuilderGNUMakeClassic::CreatePostBuildEvents(ProjectPtr proj, BuildConfigPt
             // we set all slashes to backward slashes
             wxString command = iter->GetCommand();
             command.Trim().Trim(false);
-            if(OS_WINDOWS && command.StartsWith(wxT("copy"))) { command.Replace(wxT("/"), wxT("\\")); }
+            if(OS_WINDOWS && command.StartsWith(wxT("copy"))) {
+                command.Replace(wxT("/"), wxT("\\"));
+            }
 
-            if(OS_WINDOWS && command.EndsWith(wxT("\\"))) { command.RemoveLast(); }
+            if(OS_WINDOWS && command.EndsWith(wxT("\\"))) {
+                command.RemoveLast();
+            }
 
             text << wxT("\t") << iter->GetCommand() << wxT("\n");
         }
@@ -1050,7 +1114,9 @@ bool BuilderGNUMakeClassic::HasPrebuildCommands(BuildConfigPtr bldConf) const
 
     BuildCommandList::const_iterator iter = cmds.begin();
     for(; iter != cmds.end(); iter++) {
-        if(iter->GetEnabled()) { return true; }
+        if(iter->GetEnabled()) {
+            return true;
+        }
     }
     return false;
 }
@@ -1091,7 +1157,9 @@ void BuilderGNUMakeClassic::CreatePreBuildEvents(ProjectPtr proj, BuildConfigPtr
                 text << wxT("\t") << iter->GetCommand() << wxT("\n");
             }
         }
-        if(!first) { text << wxT("\t@echo Done\n"); }
+        if(!first) {
+            text << wxT("\t@echo Done\n");
+        }
     }
 }
 
@@ -1125,6 +1193,7 @@ void BuilderGNUMakeClassic::CreateConfigsVariables(ProjectPtr proj, BuildConfigP
 
     text << "ProjectName            :=" << projectName << "\n";
     text << "ConfigurationName      :=" << name << "\n";
+    text << "WorkspaceConfiguration :=" << clCxxWorkspaceST::Get()->GetSelectedConfig()->GetName() << "\n";
     text << "WorkspacePath          :=" << ::WrapWithQuotes(workspacepath) << "\n";
     text << "ProjectPath            :=" << ::WrapWithQuotes(projectpath) << "\n";
     text << "IntermediateDirectory  :=" << bldConf->GetIntermediateDirectory() << "\n";
@@ -1147,6 +1216,7 @@ void BuilderGNUMakeClassic::CreateConfigsVariables(ProjectPtr proj, BuildConfigP
     text << "LibraryPathSwitch      :=" << cmp->GetSwitch("LibraryPath") << "\n";
     text << "PreprocessorSwitch     :=" << cmp->GetSwitch("Preprocessor") << "\n";
     text << "SourceSwitch           :=" << cmp->GetSwitch("Source") << "\n";
+    text << "OutputDirectory        :=" << bldConf->GetOutputDirectory() << "\n";
     text << "OutputFile             :=" << outputFile << "\n";
     text << "Preprocessors          :=" << ParsePreprocessor(bldConf->GetPreprocessor()) << "\n";
     text << "ObjectSwitch           :=" << cmp->GetSwitch("Object") << "\n";
@@ -1215,7 +1285,9 @@ void BuilderGNUMakeClassic::CreateConfigsVariables(ProjectPtr proj, BuildConfigP
     if(bldConf->GetPchInCommandLine()) {
         pchFile = bldConf->GetPrecompiledHeader();
         pchFile.Trim().Trim(false);
-        if(pchFile.IsEmpty() == false) { pchFile.Prepend(wxT(" -include ")).Append(wxT(" ")); }
+        if(pchFile.IsEmpty() == false) {
+            pchFile.Prepend(wxT(" -include ")).Append(wxT(" "));
+        }
     }
 
     wxString libraries = bldConf->GetLibraries();
@@ -1244,7 +1316,7 @@ void BuilderGNUMakeClassic::CreateConfigsVariables(ProjectPtr proj, BuildConfigP
     text << wxT("\n");
     text << wxT("##\n");
     text << wxT("## Common variables\n");
-    text << wxT("## AR, CXX, CC, AS, CXXFLAGS and CFLAGS can be overriden using an environment variables\n");
+    text << wxT("## AR, CXX, CC, AS, CXXFLAGS and CFLAGS can be overridden using an environment variable\n");
     text << wxT("##\n");
     text << wxT("AR       := ") << cmp->GetTool(wxT("AR")) << wxT("\n");
     text << wxT("CXX      := ") << cmp->GetTool(wxT("CXX")) << wxT("\n");
@@ -1292,10 +1364,9 @@ wxString BuilderGNUMakeClassic::ParseLibPath(const wxString& paths, const wxStri
 wxString BuilderGNUMakeClassic::ParsePreprocessor(const wxString& prep)
 {
     wxString preprocessor(wxEmptyString);
-    wxStringTokenizer tkz(prep, wxT(";"), wxTOKEN_STRTOK);
+    wxArrayString tokens = StringUtils::BuildArgv(prep);
     // prepend each include path with libpath switch
-    while(tkz.HasMoreTokens()) {
-        wxString p(tkz.NextToken());
+    for(wxString& p : tokens) {
         p.Trim().Trim(false);
         preprocessor << wxT("$(PreprocessorSwitch)") << p << wxT(" ");
     }
@@ -1319,7 +1390,9 @@ wxString BuilderGNUMakeClassic::ParseLibs(const wxString& libs)
         wxString lib(tkz.NextToken());
         TrimString(lib);
         // remove lib prefix
-        if(lib.StartsWith(wxT("lib"))) { lib = lib.Mid(3); }
+        if(lib.StartsWith(wxT("lib"))) {
+            lib = lib.Mid(3);
+        }
 
         // remove known suffixes
         if(lib.EndsWith(wxT(".a")) || lib.EndsWith(wxT(".so")) || lib.EndsWith(wxT(".dylib")) ||
@@ -1337,7 +1410,9 @@ wxString BuilderGNUMakeClassic::GetBuildCommand(const wxString& project, const w
 {
     wxString errMsg, cmd;
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
-    if(!bldConf) { return wxEmptyString; }
+    if(!bldConf) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, false, false, errMsg);
@@ -1356,7 +1431,9 @@ wxString BuilderGNUMakeClassic::GetCleanCommand(const wxString& project, const w
 {
     wxString errMsg, cmd;
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
-    if(!bldConf) { return wxEmptyString; }
+    if(!bldConf) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, false, false, errMsg);
@@ -1378,7 +1455,9 @@ wxString BuilderGNUMakeClassic::GetPOBuildCommand(const wxString& project, const
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
-    if(!proj) { return wxEmptyString; }
+    if(!proj) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, true, false, errMsg);
@@ -1391,7 +1470,9 @@ wxString BuilderGNUMakeClassic::GetPOCleanCommand(const wxString& project, const
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
-    if(!proj) { return wxEmptyString; }
+    if(!proj) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, true, false, errMsg);
@@ -1404,7 +1485,9 @@ wxString BuilderGNUMakeClassic::GetSingleFileCmd(const wxString& project, const
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
-    if(!proj) { return wxEmptyString; }
+    if(!proj) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, true, false, errMsg);
@@ -1421,12 +1504,16 @@ wxString BuilderGNUMakeClassic::GetSingleFileCmd(const wxString& project, const
         std::vector<wxString> implExtensions = { "cpp", "cxx", "cc", "c++", "c", fn.GetExt() };
         for(const wxString& ext : implExtensions) {
             fn.SetExt(ext);
-            if(fn.FileExists()) { break; }
+            if(fn.FileExists()) {
+                break;
+            }
         }
     }
 
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
-    if(!bldConf) { return wxEmptyString; }
+    if(!bldConf) {
+        return wxEmptyString;
+    }
 
     cmpType = bldConf->GetCompilerType();
     CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
@@ -1448,11 +1535,15 @@ wxString BuilderGNUMakeClassic::GetPreprocessFileCmd(const wxString& project, co
                                                      wxString& errMsg)
 {
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
-    if(!proj) { return wxEmptyString; }
+    if(!proj) {
+        return wxEmptyString;
+    }
 
     wxString cmd;
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
-    if(!bldConf) { return wxEmptyString; }
+    if(!bldConf) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, true, false, errMsg);
@@ -1484,9 +1575,13 @@ wxString BuilderGNUMakeClassic::GetPreprocessFileCmd(const wxString& project, co
 wxString BuilderGNUMakeClassic::GetCdCmd(const wxFileName& path1, const wxFileName& path2)
 {
     wxString cd_cmd(wxT("@"));
-    if(path2.GetPath().IsEmpty()) { return cd_cmd; }
+    if(path2.GetPath().IsEmpty()) {
+        return cd_cmd;
+    }
 
-    if(path1.GetPath() != path2.GetPath()) { cd_cmd << wxT("cd \"") << path2.GetPath() << wxT("\" && "); }
+    if(path1.GetPath() != path2.GetPath()) {
+        cd_cmd << wxT("cd \"") << path2.GetPath() << wxT("\" && ");
+    }
     return cd_cmd;
 }
 
@@ -1509,7 +1604,9 @@ void BuilderGNUMakeClassic::CreateCustomPostBuildEvents(BuildConfigPtr bldConf,
                 text << wxT("\t") << iter->GetCommand() << wxT("\n");
             }
         }
-        if(!first) { text << wxT("\t@echo Done\n"); }
+        if(!first) {
+            text << wxT("\t@echo Done\n");
+        }
     }
 }
 
@@ -1532,7 +1629,9 @@ void BuilderGNUMakeClassic::CreateCustomPreBuildEvents(BuildConfigPtr bldConf, w
                 text << wxT("\t") << iter->GetCommand() << wxT("\n");
             }
         }
-        if(!first) { text << wxT("\t@echo Done\n"); }
+        if(!first) {
+            text << wxT("\t@echo Done\n");
+        }
     }
 }
 
@@ -1557,12 +1656,16 @@ wxString BuilderGNUMakeClassic::GetProjectMakeCommand(const wxFileName& wspfile,
         precmpheader.Trim().Trim(false);
         preprebuild.Trim().Trim(false);
 
-        if(preprebuild.IsEmpty() == false) { makeCommand << basicMakeCommand << wxT(" PrePreBuild && "); }
+        if(preprebuild.IsEmpty() == false) {
+            makeCommand << basicMakeCommand << wxT(" PrePreBuild && ");
+        }
 
-        if(HasPrebuildCommands(bldConf)) { makeCommand << basicMakeCommand << wxT(" PreBuild && "); }
+        if(HasPrebuildCommands(bldConf)) {
+            makeCommand << basicMakeCommand << wxT(" PreBuild && ");
+        }
 
         // Run pre-compiled header compilation if any
-        if(precmpheader.IsEmpty() == false) {
+        if(precmpheader.IsEmpty() == false && (bldConf->GetPCHFlagsPolicy() != BuildConfig::kPCHJustInclude)) {
             makeCommand << basicMakeCommand << wxT(" ") << precmpheader << wxT(".gch") << wxT(" && ");
         }
     }
@@ -1596,7 +1699,9 @@ wxString BuilderGNUMakeClassic::GetProjectMakeCommand(ProjectPtr proj, const wxS
     buildTool = EnvironmentConfig::Instance()->ExpandVariables(buildTool, true);
     basicMakeCommand << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\" ");
 
-    if(bAddCleanTarget) { makeCommand << basicMakeCommand << wxT(" clean && "); }
+    if(bAddCleanTarget) {
+        makeCommand << basicMakeCommand << wxT(" clean && ");
+    }
 
     if(bldConf && !bCleanOnly) {
         wxString preprebuild = bldConf->GetPreBuildCustom();
@@ -1606,14 +1711,16 @@ wxString BuilderGNUMakeClassic::GetProjectMakeCommand(ProjectPtr proj, const wxS
 
         makeCommand << basicMakeCommand << " MakeIntermediateDirs && ";
 
-        if(!preprebuild.IsEmpty()) { makeCommand << basicMakeCommand << wxT(" PrePreBuild && "); }
+        if(!preprebuild.IsEmpty()) {
+            makeCommand << basicMakeCommand << wxT(" PrePreBuild && ");
+        }
 
         if(bIncludePreBuild && HasPrebuildCommands(bldConf)) {
             makeCommand << basicMakeCommand << wxT(" PreBuild && ");
         }
 
         // Run pre-compiled header compilation if any
-        if(!precmpheader.IsEmpty()) {
+        if(!precmpheader.IsEmpty() && (bldConf->GetPCHFlagsPolicy() != BuildConfig::kPCHJustInclude)) {
             makeCommand << basicMakeCommand << wxT(" ") << precmpheader << wxT(".gch") << wxT(" && ");
         }
     }
@@ -1632,18 +1739,30 @@ void BuilderGNUMakeClassic::CreatePreCompiledHeaderTarget(BuildConfigPtr bldConf
     wxString filename = bldConf->GetPrecompiledHeader();
     filename.Trim().Trim(false);
 
-    if(filename.IsEmpty()) return;
+    if(filename.IsEmpty())
+        return;
+
+    auto pchPolicy = bldConf->GetPCHFlagsPolicy();
+    if(pchPolicy == BuildConfig::kPCHJustInclude) {
+        // no need to add rule here
+        return;
+    }
 
     text << wxT("\n");
     text << wxT("# PreCompiled Header\n");
     text << filename << wxT(".gch: ") << filename << wxT("\n");
-    if(bldConf->GetPCHFlagsPolicy() == BuildConfig::kPCHPolicyReplace) {
+    switch(pchPolicy) {
+    case BuildConfig::kPCHPolicyReplace:
         text << wxT("\t") << DoGetCompilerMacro(filename) << wxT(" $(SourceSwitch) ") << filename
              << wxT(" $(PCHCompileFlags)\n");
-
-    } else { // BuildConfig::kPCHPolicyAppend
+        break;
+    case BuildConfig::kPCHPolicyAppend:
         text << wxT("\t") << DoGetCompilerMacro(filename) << wxT(" $(SourceSwitch) ") << filename
              << wxT(" $(PCHCompileFlags) $(CXXFLAGS) $(IncludePath)\n");
+        break;
+    case BuildConfig::kPCHJustInclude:
+        // for completeness
+        break;
     }
     text << wxT("\n");
 }
@@ -1653,7 +1772,9 @@ wxString BuilderGNUMakeClassic::GetPORebuildCommand(const wxString& project, con
 {
     wxString errMsg, cmd;
     ProjectPtr proj = clCxxWorkspaceST::Get()->FindProjectByName(project, errMsg);
-    if(!proj) { return wxEmptyString; }
+    if(!proj) {
+        return wxEmptyString;
+    }
 
     // generate the makefile
     Export(project, confToBuild, arguments, true, false, errMsg);
@@ -1668,10 +1789,12 @@ wxString BuilderGNUMakeClassic::GetBuildToolCommand(const wxString& project, con
     wxString buildTool;
 
     BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
-    if(!bldConf) return wxEmptyString;
+    if(!bldConf)
+        return wxEmptyString;
 
     CompilerPtr compiler = bldConf->GetCompiler();
-    if(!compiler) return wxEmptyString;
+    if(!compiler)
+        return wxEmptyString;
 
     if(isCommandlineCommand) {
         buildTool = compiler->GetTool("MAKE");
@@ -1715,11 +1838,15 @@ wxString BuilderGNUMakeClassic::DoGetTargetPrefix(const wxFileName& filename, co
     wxString lastDir;
     wxString ret;
 
-    if(cwd == filename.GetPath()) return wxEmptyString;
+    if(cwd == filename.GetPath())
+        return wxEmptyString;
 
-    if(cmp && cmp->GetObjectNameIdenticalToFileName()) return wxEmptyString;
+    if(cmp && cmp->GetObjectNameIdenticalToFileName())
+        return wxEmptyString;
 
-    if(cwd == filename.GetPath()) { return wxEmptyString; }
+    if(cwd == filename.GetPath()) {
+        return wxEmptyString;
+    }
 
     // remove cwd from filename
     wxFileName relpath = filename;
@@ -1737,7 +1864,9 @@ wxString BuilderGNUMakeClassic::DoGetTargetPrefix(const wxFileName& filename, co
             lastDir = wxT("cur");
         }
 
-        if(lastDir.IsEmpty() == false) { lastDir << wxT("_"); }
+        if(lastDir.IsEmpty() == false) {
+            lastDir << wxT("_");
+        }
 
         ret += lastDir;
     }
@@ -1781,7 +1910,9 @@ bool BuilderGNUMakeClassic::HasPostbuildCommands(BuildConfigPtr bldConf) const
 
     BuildCommandList::const_iterator iter = cmds.begin();
     for(; iter != cmds.end(); iter++) {
-        if(iter->GetEnabled()) { return true; }
+        if(iter->GetEnabled()) {
+            return true;
+        }
     }
     return false;
 }
