@@ -2,6 +2,7 @@
 #define CLDATAVIEWLISTCTRL_H
 
 #include "clTreeCtrl.h"
+
 #include <unordered_map>
 #include <wx/dataview.h>
 
@@ -37,6 +38,18 @@ public:
                        const wxSize& size = wxDefaultSize, long style = 0);
     virtual ~clDataViewListCtrl();
 
+    void ScrollToBottom();
+
+    /**
+     * @brief make row the first visible row in the view
+     */
+    void SetFirstVisibleRow(size_t row);
+
+    /**
+     * @brief center row in the view
+     */
+    void CenterRow(size_t row);
+
     /**
      * @brief how many items can scroll in the view?
      */
@@ -187,12 +200,12 @@ public:
      * @brief Selects given row.
      */
     void SelectRow(size_t row);
-    
+
     /**
      * @brief Unselects given row
      */
     void UnselectRow(size_t row);
-    
+
     /**
      * @brief Returns true if row is selected
      */
