@@ -1,3 +1,5 @@
+#include "clFileSystemWorkspace.hpp"
+
 #include "CompileCommandsGenerator.h"
 #include "JSON.h"
 #include "NewFileSystemWorkspaceDialog.h"
@@ -6,10 +8,11 @@
 #include "build_settings_config.h"
 #include "clConsoleBase.h"
 #include "clFileSystemEvent.h"
-#include "clFileSystemWorkspace.hpp"
 #include "clFileSystemWorkspaceView.hpp"
 #include "clFilesCollector.h"
+#include "clKeyboardManager.h"
 #include "clSFTPEvent.h"
+#include "clShellHelper.hpp"
 #include "clWorkspaceManager.h"
 #include "clWorkspaceView.h"
 #include "codelite_events.h"
@@ -24,9 +27,10 @@
 #include "globals.h"
 #include "imanager.h"
 #include "macromanager.h"
-#include "parse_thread.h"
+#include "macros.h"
 #include "processreaderthread.h"
 #include "shell_command.h"
+
 #include <thread>
 #include <wx/msgdlg.h>
 #include <wx/tokenzr.h>
@@ -48,6 +52,7 @@
     }
 
 wxDEFINE_EVENT(wxEVT_FS_SCAN_COMPLETED, clFileSystemEvent);
+wxDEFINE_EVENT(wxEVT_FS_NEW_WORKSPACE_FILE_CREATED, clFileSystemEvent);
 clFileSystemWorkspace::clFileSystemWorkspace(bool dummy)
     : m_dummy(dummy)
 {
@@ -55,13 +60,13 @@ clFileSystemWorkspace::clFileSystemWorkspace(bool dummy)
     if(!dummy) {
         EventNotifier::Get()->Bind(wxEVT_CMD_CLOSE_WORKSPACE, &clFileSystemWorkspace::OnCloseWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_CMD_OPEN_WORKSPACE, &clFileSystemWorkspace::OnOpenWorkspace, this);
+        EventNotifier::Get()->Bind(wxEVT_CMD_RELOAD_WORKSPACE, &clFileSystemWorkspace::OnReloadWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_CMD_CREATE_NEW_WORKSPACE, &clFileSystemWorkspace::OnNewWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_ALL_EDITORS_CLOSED, &clFileSystemWorkspace::OnAllEditorsClosed, this);
         EventNotifier::Get()->Bind(wxEVT_FS_SCAN_COMPLETED, &clFileSystemWorkspace::OnScanCompleted, this);
         EventNotifier::Get()->Bind(wxEVT_CMD_RETAG_WORKSPACE, &clFileSystemWorkspace::OnParseWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_CMD_RETAG_WORKSPACE_FULL, &clFileSystemWorkspace::OnParseWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_SAVE_SESSION_NEEDED, &clFileSystemWorkspace::OnSaveSession, this);
-        Bind(wxPARSE_THREAD_SCAN_INCLUDES_DONE, &clFileSystemWorkspace::OnParseThreadScanIncludeCompleted, this);
         EventNotifier::Get()->Bind(wxEVT_SOURCE_CONTROL_PULLED, &clFileSystemWorkspace::OnSourceControlPulled, this);
 
         // Build events
@@ -96,6 +101,7 @@ clFileSystemWorkspace::~clFileSystemWorkspace()
     if(!m_dummy) {
         EventNotifier::Get()->Unbind(wxEVT_CMD_CLOSE_WORKSPACE, &clFileSystemWorkspace::OnCloseWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_OPEN_WORKSPACE, &clFileSystemWorkspace::OnOpenWorkspace, this);
+        EventNotifier::Get()->Unbind(wxEVT_CMD_RELOAD_WORKSPACE, &clFileSystemWorkspace::OnReloadWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_CREATE_NEW_WORKSPACE, &clFileSystemWorkspace::OnNewWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_ALL_EDITORS_CLOSED, &clFileSystemWorkspace::OnAllEditorsClosed, this);
         EventNotifier::Get()->Unbind(wxEVT_FS_SCAN_COMPLETED, &clFileSystemWorkspace::OnScanCompleted, this);
@@ -104,7 +110,6 @@ clFileSystemWorkspace::~clFileSystemWorkspace()
         // parsing event
         EventNotifier::Get()->Unbind(wxEVT_CMD_RETAG_WORKSPACE, &clFileSystemWorkspace::OnParseWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_RETAG_WORKSPACE_FULL, &clFileSystemWorkspace::OnParseWorkspace, this);
-        Unbind(wxPARSE_THREAD_SCAN_INCLUDES_DONE, &clFileSystemWorkspace::OnParseThreadScanIncludeCompleted, this);
         EventNotifier::Get()->Unbind(wxEVT_SOURCE_CONTROL_PULLED, &clFileSystemWorkspace::OnSourceControlPulled, this);
 
         // Build events
@@ -187,8 +192,7 @@ void clFileSystemWorkspace::CacheFiles(bool force)
         [=](const wxString& rootFolder) {
             clFilesScanner fs;
             std::vector<wxString> files;
-            wxStringSet_t excludeFolders = { ".git", ".svn", ".codelite" };
-            fs.Scan(rootFolder, files, GetFilesMask(), "", excludeFolders);
+            wxStringSet_t excludeFolders = { ".git", ".svn", ".codelite", ".ctagsd" };
 
             wxString excludePaths = GetExcludeFolders();
             wxArrayString paths = StringUtils::BuildArgv(excludePaths);
@@ -201,7 +205,9 @@ void clFileSystemWorkspace::CacheFiles(bool force)
                     if(excludePath.IsEmpty()) {
                         continue;
                     }
-                    excludeFolders.insert(excludePath);
+
+                    wxFileName fnpath(excludePath, "");
+                    excludeFolders.insert(fnpath.GetPath());
                 }
             }
             fs.Scan(rootFolder, files, GetFilesMask(), "", excludeFolders);
@@ -234,13 +240,8 @@ void clFileSystemWorkspace::OnBuildEnded(clBuildEvent& event) { event.Skip(); }
 void clFileSystemWorkspace::OnOpenWorkspace(clCommandEvent& event)
 {
     event.Skip();
-    wxFileName workspaceFile(event.GetFileName());
-
-    // Test that this is our workspace
-    if(m_settings.IsOk(workspaceFile) && Load(workspaceFile)) {
+    if(OpenWorkspace(event.GetFileName())) {
         event.Skip(false);
-        DoOpen();
-
     } else {
         m_filename.Clear();
     }
@@ -249,9 +250,8 @@ void clFileSystemWorkspace::OnOpenWorkspace(clCommandEvent& event)
 void clFileSystemWorkspace::OnCloseWorkspace(clCommandEvent& event)
 {
     event.Skip();
-    if(m_isLoaded) {
+    if(CloseWorkspace()) {
         event.Skip(false);
-        DoClose();
     }
 }
 
@@ -299,6 +299,12 @@ void clFileSystemWorkspace::RestoreSession()
 
 void clFileSystemWorkspace::DoOpen()
 {
+    // Close any opened workspace
+    auto frame = EventNotifier::Get()->TopFrame();
+    wxCommandEvent eventCloseWsp(wxEVT_COMMAND_MENU_SELECTED, XRCID("close_workspace"));
+    eventCloseWsp.SetEventObject(frame);
+    frame->GetEventHandler()->ProcessEvent(eventCloseWsp);
+
     // set the working directory to the workspace view
     ::wxSetWorkingDirectory(GetFileName().GetPath());
 
@@ -334,8 +340,9 @@ void clFileSystemWorkspace::DoOpen()
     clWorkspaceManager::Get().SetWorkspace(this);
 
     // Notify that the a new workspace is loaded
-    wxCommandEvent event(wxEVT_WORKSPACE_LOADED);
+    clWorkspaceEvent event(wxEVT_WORKSPACE_LOADED);
     event.SetString(GetFileName().GetFullPath());
+    event.SetFileName(GetFileName().GetFullPath());
     EventNotifier::Get()->AddPendingEvent(event);
 
     // Update the build configurations button
@@ -344,18 +351,14 @@ void clFileSystemWorkspace::DoOpen()
     // and finally, request codelite to keep this workspace in the recently opened workspace list
     clGetManager()->AddWorkspaceToRecentlyUsedList(m_filename);
 
-    TagsManagerST::Get()->CloseDatabase();
-    TagsManagerST::Get()->OpenDatabase(fnFolder.GetFullPath());
-
-    // Update the parser paths with the active configuration
-    UpdateParserPaths();
-
     // Cache the source files from the workspace directories
     CacheFiles();
 
+    // mark the workspace as loaded before restoring the session
+    m_isLoaded = true;
+
     // Load the workspace session (if any)
     CallAfter(&clFileSystemWorkspace::RestoreSession);
-    m_isLoaded = true;
 }
 
 void clFileSystemWorkspace::DoClose()
@@ -373,19 +376,14 @@ void clFileSystemWorkspace::DoClose()
     // Clear the UI
     GetView()->Clear();
 
-    // Restore the parser search paths
-    const wxArrayString& paths = TagsManagerST::Get()->GetCtagsOptions().GetParserSearchPaths();
-    ParseThreadST::Get()->SetSearchPaths(paths, {});
-    clDEBUG() << "Parser paths are now set to:" << paths;
-
     // Notify codelite to close the currently opened workspace
     wxCommandEvent eventClose(wxEVT_MENU, wxID_CLOSE_ALL);
     eventClose.SetEventObject(EventNotifier::Get()->TopFrame());
     EventNotifier::Get()->TopFrame()->GetEventHandler()->ProcessEvent(eventClose);
 
     // Notify workspace closed event
-    wxCommandEvent event(wxEVT_WORKSPACE_CLOSED);
-    EventNotifier::Get()->ProcessEvent(event);
+    clWorkspaceEvent event_closed(wxEVT_WORKSPACE_CLOSED);
+    EventNotifier::Get()->ProcessEvent(event_closed);
 
     // Free the database
     TagsManagerST::Get()->CloseDatabase();
@@ -427,7 +425,7 @@ clFileSystemWorkspace& clFileSystemWorkspace::Get()
     return wsp;
 }
 
-void clFileSystemWorkspace::New(const wxString& folder) { DoCreate("", folder, true); }
+void clFileSystemWorkspace::New(const wxString& folder, const wxString& name) { DoCreate(name, folder, true); }
 
 void clFileSystemWorkspace::OnScanCompleted(clFileSystemEvent& event)
 {
@@ -458,82 +456,11 @@ void clFileSystemWorkspace::Parse(bool fullParse)
         return;
     }
 
-    // in the case of re-tagging the entire workspace and full re-tagging is enabled
-    // it is faster to drop the tables instead of deleting
     if(fullParse) {
-        TagsManagerST::Get()->GetDatabase()->RecreateDatabase();
+        TagsManagerST::Get()->ParseWorkspaceFull(GetFileName().GetPath());
+    } else {
+        TagsManagerST::Get()->ParseWorkspaceIncremental();
     }
-
-    UpdateParserPaths();
-
-    // Create a parsing request
-    ParseRequest* parsingRequest = new ParseRequest(this);
-
-    // use a deep copy to endure thread safety
-    wxArrayString files;
-    files.Alloc(m_files.GetSize());
-    for(const wxFileName& fn : m_files) {
-        // filter any non valid coding file
-        files.push_back(fn.GetFullPath());
-    }
-    parsingRequest->SetWorkspaceFiles(files);
-    parsingRequest->SetType(ParseRequest::PR_PARSEINCLUDES);
-    parsingRequest->SetDbfile(TagsManagerST::Get()->GetDatabase()->GetDatabaseFileName().GetFullPath());
-    parsingRequest->SetQuickRetag(!fullParse);
-    ParseThreadST::Get()->Add(parsingRequest);
-    clGetManager()->SetStatusMessage(_("Scanning for files to parse..."));
-}
-
-void clFileSystemWorkspace::OnParseThreadScanIncludeCompleted(clParseThreadEvent& event)
-{
-    clGetManager()->SetStatusMessage(_("Parsing..."));
-
-    wxBusyCursor busyCursor;
-    const wxArrayString& files = event.GetFiles();
-
-    wxStringSet_t S;
-    S.reserve(files.size() + m_files.GetSize());
-
-    for(const wxString& file : files) {
-        S.insert(file);
-    }
-
-    // add to this set the workspace files to create a unique list of
-    // files
-    for(const wxFileName& fn : m_files) {
-        S.insert(fn.GetFullPath());
-    }
-
-    // recreate the list in the form of vector (the API requirs vector)
-    std::vector<wxString> vFiles;
-    vFiles.reserve(S.size());
-    vFiles.insert(vFiles.end(), S.begin(), S.end());
-
-    // tag'em
-    TagsManagerST::Get()->RetagFiles(vFiles, event.IsQuickParse() ? TagsManager::Retag_Quick : TagsManager::Retag_Full);
-}
-
-void clFileSystemWorkspace::UpdateParserPaths()
-{
-    if(!GetConfig()) {
-        return;
-    }
-
-    // Apply the environment (incase there are backtick, we spawn a helper process)
-    const clEnvList_t envlist = GetEnvList();
-    clEnvironment env(&envlist);
-
-    // Update the parser paths
-    wxArrayString uniquePaths = GetConfig()->GetSearchPaths(GetFileName());
-
-    // Expand any macros
-    for(wxString& path : uniquePaths) {
-        path = MacroManager::Instance()->Expand(path, nullptr, "", "");
-    }
-
-    ParseThreadST::Get()->SetSearchPaths(uniquePaths, {});
-    clDEBUG() << "[" << GetConfig()->GetName() << "]"
-              << "Parser paths are now set to:" << uniquePaths;
 }
 
 void clFileSystemWorkspace::Close() { DoClose(); }
@@ -557,9 +484,6 @@ wxString clFileSystemWorkspace::GetTargetCommand(const wxString& target) const
     const auto& M = m_settings.GetSelectedConfig()->GetBuildTargets();
     if(M.count(target)) {
         wxString cmd = M.find(target)->second;
-        if(!GetConfig()->IsRemoteEnabled()) {
-            ::WrapInShell(cmd);
-        }
         return cmd;
     }
     return wxEmptyString;
@@ -571,12 +495,15 @@ void clFileSystemWorkspace::OnBuildProcessTerminated(clProcessEvent& event)
         wxDELETE(m_buildProcess);
         DoPrintBuildMessage(event.GetOutput());
 
-        clCommandEvent e(wxEVT_SHELL_COMMAND_PROCESS_ENDED);
+        clBuildEvent e(wxEVT_BUILD_PROCESS_ENDED);
         EventNotifier::Get()->AddPendingEvent(e);
 
-        // Notify about build process started
+        // Notify about build process ended to plugins
         clBuildEvent eventStopped(wxEVT_BUILD_ENDED);
         EventNotifier::Get()->AddPendingEvent(eventStopped);
+
+        // remove any temporary scripts generated by our helper
+        m_shell_helper.Cleanup();
     }
 }
 
@@ -589,7 +516,7 @@ void clFileSystemWorkspace::OnBuildProcessOutput(clProcessEvent& event)
 
 void clFileSystemWorkspace::DoPrintBuildMessage(const wxString& message)
 {
-    clCommandEvent e(wxEVT_SHELL_COMMAND_ADDLINE);
+    clBuildEvent e(wxEVT_BUILD_PROCESS_ADDLINE);
     e.SetString(message);
     EventNotifier::Get()->AddPendingEvent(e);
 }
@@ -610,6 +537,10 @@ void clFileSystemWorkspace::Initialise()
     }
     m_view = new clFileSystemWorkspaceView(clGetManager()->GetWorkspaceView()->GetBook(), GetWorkspaceType());
     clGetManager()->GetWorkspaceView()->AddPage(m_view, GetWorkspaceType());
+    auto accel_manager = clKeyboardManager::Get();
+
+    // register global accelerators entries
+    accel_manager->AddAccelerator(_("File System Workspace"), { { "fsw_refresh_current_folder", _("Refresh") } });
 }
 
 void clFileSystemWorkspace::OnExecute(clExecuteEvent& event)
@@ -630,6 +561,8 @@ void clFileSystemWorkspace::OnExecute(clExecuteEvent& event)
     console->SetWorkingDirectory(wd);
     console->SetWaitWhenDone(true);
     console->SetSink(this);
+    console->SetEnvironment(envList);
+
     if(console->Start()) {
         m_execPID = console->GetPid();
     }
@@ -652,11 +585,31 @@ clEnvList_t clFileSystemWorkspace::GetEnvList()
     // Add the global variables
     envstr += envMap.String();
     envstr += "\n";
+
+    // include special environment variable with the default compiler paths
+    const wxString& compiler_name = GetConfig()->GetCompiler();
+    if(!compiler_name.empty()) {
+        auto cmp = BuildSettingsConfigST::Get()->GetCompiler(compiler_name);
+        auto paths = cmp->GetDefaultIncludePaths();
+        if(!paths.empty()) {
+            wxString env_value;
+            for(const auto& path : paths) {
+                if(!env_value.empty()) {
+                    env_value << ";";
+                }
+                env_value << path;
+            }
+            envstr += "CXX_INCLUDE_PATHS=" + env_value + "\n";
+        }
+    }
+
+    // and finally, include the user environment variables
     envstr += GetConfig()->GetEnvironment();
 
     // Append the workspace environment
     envstr = MacroManager::Instance()->Expand(envstr, nullptr, wxEmptyString);
     envList = FileUtils::CreateEnvironment(envstr);
+
     return envList;
 }
 
@@ -764,37 +717,59 @@ void clFileSystemWorkspace::DoBuild(const wxString& target)
         return;
     }
 
+    if(m_buildProcess) {
+        return;
+    }
+
+    m_shell_helper.Cleanup(); // clear any scripts generated earlier
+    size_t flags = IProcessCreateDefault | IProcessCreateWithHiddenConsole | IProcessRawOutput;
     // Check that the remote development is enabled AND remote build
     if(GetConfig()->IsRemoteEnabled() && GetConfig()->IsRemoteBuild()) {
-        // Launch a remote build process
-        if(m_remoteBuilder && m_remoteBuilder->IsRunning()) {
-            return;
-        }
-        m_remoteBuilder.reset(new clRemoteBuilder());
-        m_remoteBuilder->Build(GetConfig()->GetRemoteAccount(), cmd, GetConfig()->GetRemoteFolder());
+        flags |= IProcessCreateSSH;
     } else {
-        if(m_buildProcess) {
-            return;
-        }
-        // Replace all workspace macros from the command
-        cmd = MacroManager::Instance()->Expand(cmd, nullptr, wxEmptyString);
+        flags |= IProcessWrapInShell;
+    }
 
-        // Build the environment to use
-        clEnvList_t envList = GetEnvList();
+    // Replace all workspace macros from the command
+    cmd = MacroManager::Instance()->Expand(cmd, nullptr, wxEmptyString);
 
-        // Start the process with the environemt
-        m_buildProcess = ::CreateAsyncProcess(this, cmd, IProcessCreateDefault, GetFileName().GetPath(), &envList);
-        if(!m_buildProcess) {
-            clCommandEvent e(wxEVT_SHELL_COMMAND_PROCESS_ENDED);
-            EventNotifier::Get()->AddPendingEvent(e);
-        } else {
-            clCommandEvent e(wxEVT_SHELL_COMMAND_STARTED);
-            EventNotifier::Get()->AddPendingEvent(e);
+    // Build the environment to use
+    clEnvList_t envList = GetEnvList();
 
-            // Notify about build process started
-            clBuildEvent eventStart(wxEVT_BUILD_STARTED);
-            EventNotifier::Get()->AddPendingEvent(eventStart);
-        }
+    // Start the process with the environemt
+    wxString ssh_account;
+    wxString wd = GetFileName().GetPath();
+
+    // make changes if SSH is enabled here
+    if(flags & IProcessCreateSSH) {
+        ssh_account = GetConfig()->GetRemoteAccount();
+        wd = GetConfig()->GetRemoteFolder();
+    }
+
+    // See if the command requires modifications
+    if(!(flags & IProcessCreateSSH) && m_shell_helper.ProcessCommand(cmd)) {
+        cmd = m_shell_helper.GetCommand();
+        flags |= m_shell_helper.GetProcessCreateFlags();
+    }
+
+    m_buildProcess = ::CreateAsyncProcess(this, cmd, flags, wd, &envList, ssh_account);
+    if(!m_buildProcess) {
+        clBuildEvent e(wxEVT_BUILD_PROCESS_ENDED);
+        EventNotifier::Get()->AddPendingEvent(e);
+
+    } else {
+
+        // notify about starting build process.
+        // we pass the selected compiler in the event
+        clBuildEvent e(wxEVT_BUILD_PROCESS_STARTED);
+        e.SetToolchain(GetConfig()->GetCompiler());
+        EventNotifier::Get()->AddPendingEvent(e);
+
+        // Notify about build process started
+        clBuildEvent eventStart(wxEVT_BUILD_STARTED);
+        eventStart.SetConfigurationName(GetConfig()->GetName());
+        eventStart.SetProjectName(wxEmptyString);
+        EventNotifier::Get()->AddPendingEvent(eventStart);
     }
 }
 
@@ -858,10 +833,17 @@ void clFileSystemWorkspace::DoCreate(const wxString& name, const wxString& path,
     m_filename = fn;
     if(!fn.FileExists()) {
         Save(false);
+
+        // let the plugins know that we just created a new workspace file and we
+        // are about to load it
+        clFileSystemEvent createEvent(wxEVT_FS_NEW_WORKSPACE_FILE_CREATED);
+        createEvent.SetPath(m_filename.GetFullPath());
+        EventNotifier::Get()->ProcessEvent(createEvent);
     }
 
     // and load it
     if(Load(m_filename)) {
+        // Now load it
         DoOpen();
     } else {
         m_filename.Clear();
@@ -967,44 +949,55 @@ void clFileSystemWorkspace::OnDebug(clDebugEvent& event)
     wxString exe, args, wd;
     GetExecutable(exe, args, wd);
 
+    const wxString& user_debugger = GetConfig()->GetDebuggerPath();
+
     // Start the debugger
-    DebugSessionInfo startup_info;
+    DebugSessionInfo session_info;
     clDebuggerBreakpoint::Vec_t bpList;
-    startup_info.debuggerPath = MacroManager::Instance()->Expand(dinfo.path, clGetManager(), "");
-    startup_info.exeName = exe;
-    startup_info.cwd = wd;
-    startup_info.cmds = ::wxStringTokenize(dinfo.startupCommands, "\r\n", wxTOKEN_STRTOK);
+    session_info.exeName = exe;
+    session_info.cwd = wd;
+    session_info.init_file_content = GetConfig()->GetDebuggerCommands();
     clGetManager()->GetBreakpoints(bpList);
-    startup_info.bpList = bpList;
+    session_info.bpList = bpList;
 
     // Start terminal (doesn't do anything under MSW)
     m_debuggerTerminal.Clear();
     m_debuggerTerminal.Launch(dbgr->GetName());
-    startup_info.ttyName = m_debuggerTerminal.GetTty();
-    startup_info.enablePrettyPrinting = dinfo.enableGDBPrettyPrinting;
+    session_info.ttyName = m_debuggerTerminal.GetTty();
+    session_info.enablePrettyPrinting = dinfo.enableGDBPrettyPrinting;
 
     // Fire "starting" event
     clDebugEvent eventStarting(wxEVT_DEBUG_STARTING);
-    eventStarting.SetClientData(&startup_info);
+    eventStarting.SetClientData(&session_info);
     if(EventNotifier::Get()->ProcessEvent(eventStarting))
         return;
 
     // Check if any plugins provided us with new breakpoints
     if(!eventStarting.GetBreakpoints().empty()) {
-        startup_info.bpList.swap(eventStarting.GetBreakpoints());
+        session_info.bpList.swap(eventStarting.GetBreakpoints());
     }
 
-    // Get toolchain
-    CompilerPtr cmp = GetCompiler();
-    if(cmp && !cmp->GetTool("Debugger").empty()) {
-        startup_info.debuggerPath = cmp->GetTool("Debugger");
+    // Set the gdb executable
+    if(!user_debugger.empty()) {
+        session_info.debuggerPath = user_debugger;
+    } else {
+        CompilerPtr cmp = GetCompiler();
+        if(cmp && !cmp->GetTool("Debugger").empty()) {
+            session_info.debuggerPath = cmp->GetTool("Debugger");
+        }
     }
-    dbgr->Start(startup_info);
+
+    // convert the envlist into map
+    auto envlist = FileUtils::CreateEnvironment(GetConfig()->GetEnvironment());
+    //    wxStringMap_t envmap;
+    //    envmap.reserve(envlist.size());
+    //    envmap.insert(envlist.begin(), envlist.end());
+    dbgr->Start(session_info, &envlist);
 
     // Notify that debug session started
     // this will ensure that the debug layout is loaded
     clDebugEvent eventStarted(wxEVT_DEBUG_STARTED);
-    eventStarted.SetClientData(&startup_info);
+    eventStarted.SetClientData(&session_info);
     EventNotifier::Get()->ProcessEvent(eventStarted);
     // Now run the debuggee
     dbgr->Run(args, "");
@@ -1016,6 +1009,22 @@ void clFileSystemWorkspace::GetExecutable(wxString& exe, wxString& args, wxStrin
     args = GetConfig()->GetArgs();
     wd = GetConfig()->GetWorkingDirectory().IsEmpty() ? GetFileName().GetPath() : GetConfig()->GetWorkingDirectory();
 
+    // build the arguments
+    args.Replace("\r", wxEmptyString);
+    args.Replace("\n", " ");
+    auto args_arr = StringUtils::BuildArgv(args);
+
+    args.clear();
+    for(auto& arg : args_arr) {
+        if(!args.empty()) {
+            args << " ";
+        }
+        arg.Trim().Trim(false);
+        // wrap with quotes if required
+        ::WrapWithQuotes(arg);
+        args << arg;
+    }
+
     exe = MacroManager::Instance()->Expand(exe, nullptr, wxEmptyString);
     args = MacroManager::Instance()->Expand(args, nullptr, wxEmptyString);
     wd = MacroManager::Instance()->Expand(wd, nullptr, wxEmptyString);
@@ -1108,3 +1117,43 @@ wxString clFileSystemWorkspace::GetExcludeFolders() const
     }
     return wxEmptyString;
 }
+
+void clFileSystemWorkspace::SetProjectActive(const wxString& project)
+{
+    // no projects in a file system workspace
+    wxUnusedVar(project);
+}
+
+bool clFileSystemWorkspace::OpenWorkspace(const wxString& filepath)
+{
+    // Test that this is our workspace
+    if(m_settings.IsOk(filepath) && Load(filepath)) {
+        DoOpen();
+        return true;
+    } else {
+        return false;
+    }
+}
+
+bool clFileSystemWorkspace::CloseWorkspace()
+{
+    if(!IsOpen()) {
+        return false;
+    }
+    DoClose();
+    return true;
+}
+
+void clFileSystemWorkspace::OnReloadWorkspace(clCommandEvent& event)
+{
+    if(!IsOpen()) {
+        event.Skip();
+        return;
+    }
+
+    event.Skip(false);
+    wxString current_file = m_filename.GetFullPath();
+    if(CloseWorkspace()) {
+        OpenWorkspace(current_file);
+    }
+}
