@@ -1,5 +1,8 @@
-#include "clScrollBar.h"
 #include "clScrolledPanel.h"
+
+#include "clScrollBar.h"
+#include "drawingutils.h"
+
 #include <wx/dcscreen.h>
 #include <wx/log.h>
 #include <wx/settings.h>
@@ -17,7 +20,9 @@ clScrolledPanel::clScrolledPanel(wxWindow* parent, wxWindowID id, const wxPoint&
 
 bool clScrolledPanel::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
 {
-    if(!wxWindow::Create(parent, id, pos, size, style)) { return false; }
+    if(!wxWindow::Create(parent, id, pos, size, style)) {
+        return false;
+    }
     DoInitialize();
     return true;
 }
@@ -30,7 +35,7 @@ void clScrolledPanel::DoInitialize()
 
     m_hsb = new ScrollBar_t(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxSB_HORIZONTAL);
     DoPositionHScrollbar();
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
     m_vsb->Bind(wxEVT_SCROLL_THUMBTRACK, &clScrolledPanel::OnVScroll, this);
     m_vsb->Bind(wxEVT_SCROLL_LINEDOWN, &clScrolledPanel::OnVScroll, this);
     m_vsb->Bind(wxEVT_SCROLL_LINEUP, &clScrolledPanel::OnVScroll, this);
@@ -81,7 +86,8 @@ void clScrolledPanel::DoInitialize()
 #endif
     m_tmpBmp = wxBitmap(1, 1);
     m_memDC = new wxMemoryDC(m_tmpBmp);
-    m_gcdc = new wxGCDC(*m_memDC);
+    m_gcdc = new wxGCDC();
+    DrawingUtils::GetGCDC(*m_memDC, *m_gcdc);
 }
 
 clScrolledPanel::~clScrolledPanel()
@@ -89,7 +95,7 @@ clScrolledPanel::~clScrolledPanel()
     // Destory the DCs in the reverse order of their creation
     wxDELETE(m_gcdc);
     wxDELETE(m_memDC);
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
     m_vsb->Unbind(wxEVT_SCROLL_THUMBTRACK, &clScrolledPanel::OnVScroll, this);
     m_vsb->Unbind(wxEVT_SCROLL_LINEDOWN, &clScrolledPanel::OnVScroll, this);
     m_vsb->Unbind(wxEVT_SCROLL_LINEUP, &clScrolledPanel::OnVScroll, this);
@@ -119,7 +125,7 @@ clScrolledPanel::~clScrolledPanel()
     Unbind(wxEVT_LEAVE_WINDOW, &clScrolledPanel::OnLeaveWindow, this);
 }
 
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
 void clScrolledPanel::OnHScroll(wxScrollEvent& event)
 {
     int newColumn = wxNOT_FOUND;
@@ -149,7 +155,9 @@ void clScrolledPanel::OnHScroll(wxScrollEvent& event)
             steps = 0;
             direction = wxRIGHT;
         }
-        if(steps != wxNOT_FOUND) { ScrollColumns(steps, direction); }
+        if(steps != wxNOT_FOUND) {
+            ScrollColumns(steps, direction);
+        }
     }
 }
 
@@ -181,12 +189,14 @@ void clScrolledPanel::OnVScroll(wxScrollEvent& event)
             steps = 0;
             direction = wxDOWN;
         }
-        if(steps != wxNOT_FOUND) { ScrollRows(steps, direction); }
+        if(steps != wxNOT_FOUND) {
+            ScrollRows(steps, direction);
+        }
     }
 }
 #endif
 
-#if CL_USE_CUSTOM_SCROLLBAR
+#if !wxUSE_NATIVE_SCROLLBAR
 void clScrolledPanel::OnVCustomScroll(clScrollEvent& event) { ScrollToRow(event.GetPosition()); }
 void clScrolledPanel::OnHCustomScroll(clScrollEvent& event) { ScollToColumn(event.GetPosition()); }
 #endif
@@ -214,7 +224,7 @@ void clScrolledPanel::UpdateVScrollBar(int position, int thumbSize, int rangeSiz
         m_vsb->Show();
     }
 
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
     m_vsb->SetScrollbar(position, thumbSize, rangeSize, pageSize);
     m_vsb->Refresh();
 #else
@@ -229,7 +239,6 @@ void clScrolledPanel::OnCharHook(wxKeyEvent& event)
     wxKeyEvent keyDown = event;
     keyDown.SetEventType(wxEVT_KEY_DOWN);
     if(DoKeyDown(keyDown)) {
-        event.Skip(false);
         return;
     }
 
@@ -331,7 +340,9 @@ void clScrolledPanel::DoBeginDrag()
     wxTreeEvent event(wxEVT_TREE_BEGIN_DRAG);
     event.SetEventObject(this);
     GetEventHandler()->ProcessEvent(event);
-    if(!event.IsAllowed()) { return; }
+    if(!event.IsAllowed()) {
+        return;
+    }
 
     // Change the cursor indicating DnD in progress
     SetCursor(wxCURSOR_HAND);
@@ -377,11 +388,20 @@ void clScrolledPanel::DoPositionVScrollbar()
     wxSize vsbSize = m_vsb->GetSize();
 
     int height = clientRect.GetHeight();
-    if(m_hsb && m_hsb->IsShown()) { height -= m_hsb->GetSize().GetHeight(); }
+    if(m_hsb && m_hsb->IsShown()) {
+        height -= m_hsb->GetSize().GetHeight();
+    }
     int width = vsbSize.GetWidth();
     int x = clientRect.GetWidth() - vsbSize.GetWidth();
     int y = 0;
 
+    if(width < -1) {
+        width = -1;
+    }
+    if(height < -1) {
+        height = -1;
+    }
+
     m_vsb->SetSize(width, height);
     m_vsb->Move(x, y);
 }
@@ -392,7 +412,9 @@ void clScrolledPanel::DoPositionHScrollbar()
     wxSize hsbSize = m_hsb->GetSize();
 
     int width = clientRect.GetWidth();
-    if(m_vsb && m_vsb->IsShown()) { width -= m_vsb->GetSize().GetWidth(); }
+    if(m_vsb && m_vsb->IsShown()) {
+        width -= m_vsb->GetSize().GetWidth();
+    }
     int height = hsbSize.GetHeight();
     int x = 0;
     int y = clientRect.GetHeight() - hsbSize.GetHeight();
@@ -421,7 +443,7 @@ void clScrolledPanel::UpdateHScrollBar(int position, int thumbSize, int rangeSiz
     } else if(!should_show && m_hsb->IsShown()) {
         m_hsb->Hide();
     }
-#if CL_USE_NATIVE_SCROLLBAR
+#if wxUSE_NATIVE_SCROLLBAR
     m_hsb->SetScrollbar(position, thumbSize, rangeSize, pageSize);
     m_hsb->Refresh();
 #else
@@ -438,8 +460,12 @@ wxRect clScrolledPanel::GetClientArea() const
     r.SetTopLeft(wxPoint(0, 0));
 #endif
 
-    if(m_hsb && m_hsb->IsShown()) { r.SetHeight(r.GetHeight() - m_hsb->GetSize().GetHeight()); }
-    if(m_vsb && m_vsb->IsShown()) { r.SetWidth(r.GetWidth() - m_vsb->GetSize().GetWidth()); }
+    if(m_hsb && m_hsb->IsShown()) {
+        r.SetHeight(r.GetHeight() - m_hsb->GetSize().GetHeight());
+    }
+    if(m_vsb && m_vsb->IsShown()) {
+        r.SetWidth(r.GetWidth() - m_vsb->GetSize().GetWidth());
+    }
     return r;
 }
 
