@@ -6,7 +6,7 @@
 class WXDLLIMPEXP_SDK clToolBarToggleButton : public clToolBarButton
 {
 public:
-    clToolBarToggleButton(clToolBar* parent, wxWindowID id, const wxBitmap& bmp, const wxString& label = "");
+    clToolBarToggleButton(clToolBar* parent, wxWindowID id, size_t bitmapId, const wxString& label = "");
     virtual ~clToolBarToggleButton();
 };
 
