@@ -22,6 +22,9 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "project.h"
+
+#include "GCCMetadata.hpp"
 #include "ICompilerLocator.h"
 #include "asyncprocess.h"
 #include "cl_command_event.h"
@@ -36,12 +39,12 @@
 #include "macromanager.h"
 #include "macros.h"
 #include "plugin.h"
-#include "project.h"
 #include "workspace.h"
 #include "wx/arrstr.h"
 #include "wxArrayStringAppender.h"
 #include "wx_xml_compatibility.h"
 #include "xmlutils.h"
+
 #include <algorithm>
 #include <wx/app.h>
 #include <wx/ffile.h>
@@ -119,7 +122,7 @@ bool Project::Load(const wxString& path)
     if(!m_doc.Load(path)) {
         return false;
     }
-    
+
     // Workaround WX bug: load the plugins data (GetAllPluginsData will strip any trailing whitespaces)
     // and then set them back
     std::map<wxString, wxString> pluginsData;
@@ -1360,8 +1363,10 @@ void Project::SetExcludeConfigsForFile(const wxString& filename, const wxStringS
     SaveXmlFile();
 }
 
-static void ProcessIncludes(const wxArrayString& paths, const wxString& wd, wxStringSet_t& res,
-                            std::vector<wxString>& pathsVec)
+namespace
+{
+void ProcessIncludes(const wxArrayString& paths, const wxString& wd, wxStringSet_t& res,
+                     std::vector<wxString>& pathsVec)
 {
     // Convert the include paths to full path, prepend -I and add them
     for(const wxString& path : paths) {
@@ -1379,7 +1384,7 @@ static void ProcessIncludes(const wxArrayString& paths, const wxString& wd, wxSt
     }
 }
 
-static void ProcessMacros(const wxArrayString& macros, wxStringSet_t& res)
+void ProcessMacros(const wxArrayString& macros, wxStringSet_t& res)
 {
     for(const wxString& macro : macros) {
         wxString tmpMacro = macro;
@@ -1396,41 +1401,16 @@ static void ProcessMacros(const wxArrayString& macros, wxStringSet_t& res)
     }
 }
 
-static wxString GetExtraFlags(CompilerPtr compiler)
+wxString GetExtraFlags(CompilerPtr compiler)
 {
-#ifdef __WXMSW__
-    if(compiler->GetCompilerFamily() == COMPILER_FAMILY_MINGW) {
-        if(compiler->Is64BitCompiler()) {
-            return "-target x86_64-pc-windows-gnu";
-        } else {
-            return "-target i686-pc-windows-gnu";
-        }
+    wxString extra_flags;
+    if(compiler->HasMetadata()) {
+        auto md = compiler->GetMetadata();
+        extra_flags << "-target " << md.GetTarget();
     }
-#endif
-    return "";
-}
-
-static void GetExtraFlags(wxString& content, CompilerPtr compiler)
-{
-#ifdef __WXMSW__
-    if(compiler->GetCompilerFamily() == COMPILER_FAMILY_MINGW) {
-        if(!content.IsEmpty() && !content.EndsWith("\n")) {
-            content << "\n";
-        }
-        if(compiler->Is64BitCompiler()) {
-            content << "-target"
-                    << "\n"
-                    << "x86_64-pc-windows-gnu"
-                    << "\n";
-        } else {
-            content << "-target"
-                    << "\n"
-                    << "i686-pc-windows-gnu"
-                    << "\n";
-        }
-    }
-#endif
+    return extra_flags;
 }
+} // namespace
 
 wxString Project::GetCompileLineForCXXFile(const wxStringMap_t& compilersGlobalPaths, BuildConfigPtr buildConf,
                                            const wxString& filenamePlaceholder, size_t flags)
@@ -1460,9 +1440,12 @@ wxString Project::GetCompileLineForCXXFile(const wxStringMap_t& compilersGlobalP
         }
     }
 
-    wxString compilerExe = compiler->GetTool(flags & kCxxFile ? "CXX" : "CC");
-    commandLine << "clang "
-                << " -c " << filenamePlaceholder << " -o " << filenamePlaceholder << ".o " << extraFlags;
+    wxString compilerExe = (flags & kCxxFile ? "clang++" : "clang");
+    if(compiler->IsGnuCompatibleCompiler()) {
+        compilerExe = compiler->GetTool(flags & kCxxFile ? "CXX" : "CC");
+    }
+    ::WrapWithQuotes(compilerExe);
+    commandLine << compilerExe << " -c " << filenamePlaceholder << " -o " << filenamePlaceholder << ".o " << extraFlags;
 
     // Apply the environment
     EnvSetter es(NULL, NULL, GetName(), buildConf->GetName());
@@ -1492,6 +1475,15 @@ wxString Project::GetCompileLineForCXXFile(const wxStringMap_t& compilersGlobalP
         commandLine << "-I" << incl_path << " ";
     }
 
+    // Add the PCH file
+    if(buildConf->GetPchInCommandLine()) {
+        wxString pchFile = buildConf->GetPrecompiledHeader();
+        pchFile.Trim().Trim(false);
+        if(!pchFile.IsEmpty()) {
+            commandLine << "-include " << pchFile << " ";
+        }
+    }
+
     // Get the compile options
     wxString projectCompileOptions =
         (flags & kCxxFile) ? buildConf->GetCompileOptions() : buildConf->GetCCompileOptions();
@@ -1635,7 +1627,7 @@ void Project::GetCompilers(wxStringSet_t& compilers)
     }
 }
 
-void Project::ReplaceCompilers(wxStringMap_t& compilers)
+void Project::ReplaceCompilers(const wxStringMap_t& compilers)
 {
     ProjectSettingsPtr pSettings = GetSettings();
     CHECK_PTR_RET(pSettings);
@@ -2070,8 +2062,8 @@ void Project::CreateCompileFlags(const wxStringMap_t& compilersGlobalPaths)
         ProcessMacros(tmpMacros, macroSet);
 
     } else {
-        wxString cFilePattern = GetCompileLineForCXXFile(compilersGlobalPaths, buildConf, "$FileName", 0);
-        wxString cxxFilePattern = GetCompileLineForCXXFile(compilersGlobalPaths, buildConf, "$FileName", kCxxFile);
+        wxString cFilePattern = GetCompileLineForCXXFile({}, buildConf, "$FileName", 0);
+        wxString cxxFilePattern = GetCompileLineForCXXFile({}, buildConf, "$FileName", kCxxFile);
 
         wxStringSet_t pathsSet;
 
@@ -2100,6 +2092,15 @@ void Project::CreateCompileFlags(const wxStringMap_t& compilersGlobalPaths)
         compile_flags_content << path << "\n";
     }
 
+    // Write the PCH file
+    if(buildConf->GetPchInCommandLine()) {
+        wxString pchFile = buildConf->GetPrecompiledHeader();
+        pchFile.Trim().Trim(false);
+        if(!pchFile.IsEmpty()) {
+            compile_flags_content << "-include\n" << pchFile << "\n";
+        }
+    }
+
     // Write the macros
     for(const wxString& macro : macroSet) {
         compile_flags_content << macro << "\n";
@@ -2111,8 +2112,9 @@ void Project::CreateCompileFlags(const wxStringMap_t& compilersGlobalPaths)
     }
 
     // Add the target flag
-    if(cmp) {
-        GetExtraFlags(compile_flags_content, buildConf->GetCompiler());
+    if(cmp && cmp->HasMetadata()) {
+        GCCMetadata cmd = cmp->GetMetadata();
+        compile_flags_content << "-target\n" << cmd.GetTarget() << "\n";
     }
 
     // Handle h files as C++ headers
